/****************************************************************************
** Meta object code from reading C++ file 'UBGraphicsMediaItemDelegate.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/domain/UBGraphicsMediaItemDelegate.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBGraphicsMediaItemDelegate.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27UBGraphicsMediaItemDelegateE_t {};
} // unnamed namespace

template <> constexpr inline auto UBGraphicsMediaItemDelegate::qt_create_metaobjectdata<qt_meta_tag_ZN27UBGraphicsMediaItemDelegateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBGraphicsMediaItemDelegate",
        "toggleMute",
        "",
        "updateTicker",
        "time",
        "showHide",
        "show",
        "mediaStatusChanged",
        "QMediaPlayer::MediaStatus",
        "status",
        "mediaStateChanged",
        "QMediaPlayer::PlaybackState",
        "state",
        "remove",
        "canUndo",
        "togglePlayPause",
        "updatePlayPauseState",
        "totalTimeChanged",
        "newTotalTime",
        "hideToolBar"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'toggleMute'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateTicker'
        QtMocHelpers::SlotData<void(qint64)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 4 },
        }}),
        // Slot 'showHide'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'mediaStatusChanged'
        QtMocHelpers::SlotData<void(QMediaPlayer::MediaStatus)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'mediaStateChanged'
        QtMocHelpers::SlotData<void(QMediaPlayer::PlaybackState)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'togglePlayPause'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updatePlayPauseState'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'totalTimeChanged'
        QtMocHelpers::SlotData<void(qint64)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::LongLong, 18 },
        }}),
        // Slot 'hideToolBar'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBGraphicsMediaItemDelegate, qt_meta_tag_ZN27UBGraphicsMediaItemDelegateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBGraphicsMediaItemDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<UBGraphicsItemDelegate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27UBGraphicsMediaItemDelegateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27UBGraphicsMediaItemDelegateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27UBGraphicsMediaItemDelegateE_t>.metaTypes,
    nullptr
} };

void UBGraphicsMediaItemDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBGraphicsMediaItemDelegate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->toggleMute(); break;
        case 1: _t->updateTicker((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 2: _t->showHide((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->mediaStatusChanged((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::MediaStatus>>(_a[1]))); break;
        case 4: _t->mediaStateChanged((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::PlaybackState>>(_a[1]))); break;
        case 5: _t->remove((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->remove(); break;
        case 7: _t->togglePlayPause(); break;
        case 8: _t->updatePlayPauseState(); break;
        case 9: _t->totalTimeChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 10: _t->hideToolBar(); break;
        default: ;
        }
    }
}

const QMetaObject *UBGraphicsMediaItemDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBGraphicsMediaItemDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27UBGraphicsMediaItemDelegateE_t>.strings))
        return static_cast<void*>(this);
    return UBGraphicsItemDelegate::qt_metacast(_clname);
}

int UBGraphicsMediaItemDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBGraphicsItemDelegate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
