/****************************************************************************
** Meta object code from reading C++ file 'UBGraphicsMediaItem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/domain/UBGraphicsMediaItem.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBGraphicsMediaItem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19UBGraphicsMediaItemE_t {};
} // unnamed namespace

template <> constexpr inline auto UBGraphicsMediaItem::qt_create_metaobjectdata<qt_meta_tag_ZN19UBGraphicsMediaItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBGraphicsMediaItem",
        "toggleMute",
        "",
        "setMute",
        "bMute",
        "activeSceneChanged",
        "showOnDisplayChanged",
        "shown",
        "play",
        "pause",
        "stop",
        "togglePlayPause",
        "mediaError",
        "QMediaPlayer::Error",
        "errorCode"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'toggleMute'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMute'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'activeSceneChanged'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showOnDisplayChanged'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'togglePlayPause'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mediaError'
        QtMocHelpers::SlotData<void(QMediaPlayer::Error)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBGraphicsMediaItem, qt_meta_tag_ZN19UBGraphicsMediaItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBGraphicsMediaItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBGraphicsMediaItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBGraphicsMediaItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19UBGraphicsMediaItemE_t>.metaTypes,
    nullptr
} };

void UBGraphicsMediaItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBGraphicsMediaItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->toggleMute(); break;
        case 1: _t->setMute((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->activeSceneChanged(); break;
        case 3: _t->showOnDisplayChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->play(); break;
        case 5: _t->pause(); break;
        case 6: _t->stop(); break;
        case 7: _t->togglePlayPause(); break;
        case 8: _t->mediaError((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::Error>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *UBGraphicsMediaItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBGraphicsMediaItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBGraphicsMediaItemE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "UBItem"))
        return static_cast< UBItem*>(this);
    if (!strcmp(_clname, "UBGraphicsItem"))
        return static_cast< UBGraphicsItem*>(this);
    if (!strcmp(_clname, "QGraphicsRectItem"))
        return static_cast< QGraphicsRectItem*>(this);
    if (!strcmp(_clname, "UBResizableGraphicsItem"))
        return static_cast< UBResizableGraphicsItem*>(this);
    return QObject::qt_metacast(_clname);
}

int UBGraphicsMediaItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN19UBGraphicsAudioItemE_t {};
} // unnamed namespace

template <> constexpr inline auto UBGraphicsAudioItem::qt_create_metaobjectdata<qt_meta_tag_ZN19UBGraphicsAudioItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBGraphicsAudioItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBGraphicsAudioItem, qt_meta_tag_ZN19UBGraphicsAudioItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBGraphicsAudioItem::staticMetaObject = { {
    QMetaObject::SuperData::link<UBGraphicsMediaItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBGraphicsAudioItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBGraphicsAudioItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19UBGraphicsAudioItemE_t>.metaTypes,
    nullptr
} };

void UBGraphicsAudioItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBGraphicsAudioItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UBGraphicsAudioItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBGraphicsAudioItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBGraphicsAudioItemE_t>.strings))
        return static_cast<void*>(this);
    return UBGraphicsMediaItem::qt_metacast(_clname);
}

int UBGraphicsAudioItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBGraphicsMediaItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19UBGraphicsVideoItemE_t {};
} // unnamed namespace

template <> constexpr inline auto UBGraphicsVideoItem::qt_create_metaobjectdata<qt_meta_tag_ZN19UBGraphicsVideoItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBGraphicsVideoItem",
        "videoSizeChanged",
        "",
        "QSizeF",
        "newSize",
        "hasVideoChanged",
        "hasVideo",
        "mediaStateChanged",
        "QMediaPlayer::PlaybackState",
        "state",
        "activeSceneChanged",
        "mediaError",
        "QMediaPlayer::Error",
        "errorCode"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'videoSizeChanged'
        QtMocHelpers::SlotData<void(QSizeF)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'hasVideoChanged'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'mediaStateChanged'
        QtMocHelpers::SlotData<void(QMediaPlayer::PlaybackState)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'activeSceneChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mediaError'
        QtMocHelpers::SlotData<void(QMediaPlayer::Error)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBGraphicsVideoItem, qt_meta_tag_ZN19UBGraphicsVideoItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBGraphicsVideoItem::staticMetaObject = { {
    QMetaObject::SuperData::link<UBGraphicsMediaItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBGraphicsVideoItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBGraphicsVideoItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19UBGraphicsVideoItemE_t>.metaTypes,
    nullptr
} };

void UBGraphicsVideoItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBGraphicsVideoItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->videoSizeChanged((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1]))); break;
        case 1: _t->hasVideoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->mediaStateChanged((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::PlaybackState>>(_a[1]))); break;
        case 3: _t->activeSceneChanged(); break;
        case 4: _t->mediaError((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::Error>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *UBGraphicsVideoItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBGraphicsVideoItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBGraphicsVideoItemE_t>.strings))
        return static_cast<void*>(this);
    return UBGraphicsMediaItem::qt_metacast(_clname);
}

int UBGraphicsVideoItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBGraphicsMediaItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
