/****************************************************************************
** Meta object code from reading C++ file 'UBFeaturesActionBar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/gui/UBFeaturesActionBar.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBFeaturesActionBar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19UBFeaturesActionBarE_t {};
} // unnamed namespace

template <> constexpr inline auto UBFeaturesActionBar::qt_create_metaobjectdata<qt_meta_tag_ZN19UBFeaturesActionBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBFeaturesActionBar",
        "searchElement",
        "",
        "text",
        "newFolderToCreate",
        "deleteElements",
        "const UBFeaturesMimeData*",
        "data",
        "addToFavorites",
        "removeFromFavorites",
        "addElementsToFavorite",
        "removeElementsFromFavorite",
        "deleteSelectedElements",
        "rescanModel",
        "onSearchTextChanged",
        "txt",
        "onActionNewFolder",
        "onActionAddToFavorites",
        "onActionRemoveFromFavorites",
        "onActionTrash",
        "onActionRescanModel",
        "lockIt",
        "unlockIt"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'searchElement'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'newFolderToCreate'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deleteElements'
        QtMocHelpers::SignalData<void(const UBFeaturesMimeData *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'addToFavorites'
        QtMocHelpers::SignalData<void(const UBFeaturesMimeData *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'removeFromFavorites'
        QtMocHelpers::SignalData<void(const UBFeaturesMimeData *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'addElementsToFavorite'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removeElementsFromFavorite'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deleteSelectedElements'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rescanModel'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSearchTextChanged'
        QtMocHelpers::SlotData<void(QString)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'onActionNewFolder'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onActionAddToFavorites'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onActionRemoveFromFavorites'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onActionTrash'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onActionRescanModel'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'lockIt'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'unlockIt'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBFeaturesActionBar, qt_meta_tag_ZN19UBFeaturesActionBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBFeaturesActionBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBFeaturesActionBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBFeaturesActionBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19UBFeaturesActionBarE_t>.metaTypes,
    nullptr
} };

void UBFeaturesActionBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBFeaturesActionBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->searchElement((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newFolderToCreate(); break;
        case 2: _t->deleteElements((*reinterpret_cast<std::add_pointer_t<const UBFeaturesMimeData*>>(_a[1]))); break;
        case 3: _t->addToFavorites((*reinterpret_cast<std::add_pointer_t<const UBFeaturesMimeData*>>(_a[1]))); break;
        case 4: _t->removeFromFavorites((*reinterpret_cast<std::add_pointer_t<const UBFeaturesMimeData*>>(_a[1]))); break;
        case 5: _t->addElementsToFavorite(); break;
        case 6: _t->removeElementsFromFavorite(); break;
        case 7: _t->deleteSelectedElements(); break;
        case 8: _t->rescanModel(); break;
        case 9: _t->onSearchTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->onActionNewFolder(); break;
        case 11: _t->onActionAddToFavorites(); break;
        case 12: _t->onActionRemoveFromFavorites(); break;
        case 13: _t->onActionTrash(); break;
        case 14: _t->onActionRescanModel(); break;
        case 15: _t->lockIt(); break;
        case 16: _t->unlockIt(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesActionBar::*)(const QString & )>(_a, &UBFeaturesActionBar::searchElement, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesActionBar::*)()>(_a, &UBFeaturesActionBar::newFolderToCreate, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesActionBar::*)(const UBFeaturesMimeData * )>(_a, &UBFeaturesActionBar::deleteElements, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesActionBar::*)(const UBFeaturesMimeData * )>(_a, &UBFeaturesActionBar::addToFavorites, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesActionBar::*)(const UBFeaturesMimeData * )>(_a, &UBFeaturesActionBar::removeFromFavorites, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesActionBar::*)()>(_a, &UBFeaturesActionBar::addElementsToFavorite, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesActionBar::*)()>(_a, &UBFeaturesActionBar::removeElementsFromFavorite, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesActionBar::*)()>(_a, &UBFeaturesActionBar::deleteSelectedElements, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesActionBar::*)()>(_a, &UBFeaturesActionBar::rescanModel, 8))
            return;
    }
}

const QMetaObject *UBFeaturesActionBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBFeaturesActionBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBFeaturesActionBarE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int UBFeaturesActionBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void UBFeaturesActionBar::searchElement(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UBFeaturesActionBar::newFolderToCreate()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UBFeaturesActionBar::deleteElements(const UBFeaturesMimeData * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UBFeaturesActionBar::addToFavorites(const UBFeaturesMimeData * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UBFeaturesActionBar::removeFromFavorites(const UBFeaturesMimeData * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void UBFeaturesActionBar::addElementsToFavorite()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void UBFeaturesActionBar::removeElementsFromFavorite()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void UBFeaturesActionBar::deleteSelectedElements()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void UBFeaturesActionBar::rescanModel()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
