/****************************************************************************
** Meta object code from reading C++ file 'UBPodcastController.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/podcast/UBPodcastController.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBPodcastController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19UBPodcastControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto UBPodcastController::qt_create_metaobjectdata<qt_meta_tag_ZN19UBPodcastControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBPodcastController",
        "recordingStateChanged",
        "",
        "UBPodcastController::RecordingState",
        "recordingProgressChanged",
        "ms",
        "start",
        "stop",
        "pause",
        "unpause",
        "toggleRecordingPalette",
        "visible",
        "recordToggled",
        "record",
        "pauseToggled",
        "processScreenGrabingTimerEvent",
        "processScenePaintEvent",
        "sceneChanged",
        "QList<QRectF>",
        "region",
        "sceneBackgroundChanged",
        "activeSceneChanged",
        "applicationMainModeChanged",
        "UBApplicationController::MainMode",
        "pMode",
        "applicationDesktopMode",
        "displayed",
        "webActiveWebPageChanged",
        "WebView*",
        "pWebView",
        "encodingStatus",
        "pStatus",
        "encodingFinished",
        "ok",
        "applicationAboutToQuit",
        "groupActionTriggered",
        "QAction*",
        "actionToggled",
        "updateActionState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'recordingStateChanged'
        QtMocHelpers::SignalData<void(UBPodcastController::RecordingState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'recordingProgressChanged'
        QtMocHelpers::SignalData<void(qint64)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 5 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unpause'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleRecordingPalette'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'recordToggled'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'pauseToggled'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'processScreenGrabingTimerEvent'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processScenePaintEvent'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sceneChanged'
        QtMocHelpers::SlotData<void(const QList<QRectF> &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'sceneBackgroundChanged'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activeSceneChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applicationMainModeChanged'
        QtMocHelpers::SlotData<void(UBApplicationController::MainMode)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'applicationDesktopMode'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'webActiveWebPageChanged'
        QtMocHelpers::SlotData<void(WebView *)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'encodingStatus'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'encodingFinished'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'applicationAboutToQuit'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'groupActionTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'actionToggled'
        QtMocHelpers::SlotData<void(bool)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'updateActionState'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBPodcastController, qt_meta_tag_ZN19UBPodcastControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBPodcastController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBPodcastControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBPodcastControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19UBPodcastControllerE_t>.metaTypes,
    nullptr
} };

void UBPodcastController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBPodcastController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->recordingStateChanged((*reinterpret_cast<std::add_pointer_t<UBPodcastController::RecordingState>>(_a[1]))); break;
        case 1: _t->recordingProgressChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 2: _t->start(); break;
        case 3: _t->stop(); break;
        case 4: _t->pause(); break;
        case 5: _t->unpause(); break;
        case 6: _t->toggleRecordingPalette((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->recordToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->pauseToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->processScreenGrabingTimerEvent(); break;
        case 10: _t->processScenePaintEvent(); break;
        case 11: _t->sceneChanged((*reinterpret_cast<std::add_pointer_t<QList<QRectF>>>(_a[1]))); break;
        case 12: _t->sceneBackgroundChanged(); break;
        case 13: _t->activeSceneChanged(); break;
        case 14: _t->applicationMainModeChanged((*reinterpret_cast<std::add_pointer_t<UBApplicationController::MainMode>>(_a[1]))); break;
        case 15: _t->applicationDesktopMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->webActiveWebPageChanged((*reinterpret_cast<std::add_pointer_t<WebView*>>(_a[1]))); break;
        case 17: _t->encodingStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->encodingFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->applicationAboutToQuit(); break;
        case 20: _t->groupActionTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 21: _t->actionToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->updateActionState(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBPodcastController::*)(UBPodcastController::RecordingState )>(_a, &UBPodcastController::recordingStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBPodcastController::*)(qint64 )>(_a, &UBPodcastController::recordingProgressChanged, 1))
            return;
    }
}

const QMetaObject *UBPodcastController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBPodcastController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBPodcastControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBPodcastController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void UBPodcastController::recordingStateChanged(UBPodcastController::RecordingState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UBPodcastController::recordingProgressChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
