/****************************************************************************
** Meta object code from reading C++ file 'UBBoardController.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/board/UBBoardController.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBBoardController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17UBBoardControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto UBBoardController::qt_create_metaobjectdata<qt_meta_tag_ZN17UBBoardControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBBoardController",
        "newPageAdded",
        "",
        "activeSceneChanged",
        "zoomChanged",
        "pZoomFactor",
        "penColorChanged",
        "controlViewportChanged",
        "backgroundChanged",
        "cacheEnabled",
        "documentReorganized",
        "index",
        "displayMetadata",
        "QMap<QString,QString>",
        "metadata",
        "pageSelectionChanged",
        "npapiWidgetCreated",
        "Url",
        "showDocumentsDialog",
        "showKeyboard",
        "show",
        "togglePodcast",
        "checked",
        "blackout",
        "addScene",
        "std::shared_ptr<UBDocumentProxy>",
        "proxy",
        "sceneIndex",
        "replaceActiveIfEmpty",
        "std::shared_ptr<UBGraphicsScene>",
        "scene",
        "duplicateScene",
        "importPage",
        "clearScene",
        "clearSceneItems",
        "clearSceneAnnotation",
        "clearSceneBackground",
        "zoomIn",
        "QPointF",
        "scenePoint",
        "zoomOut",
        "zoomRestore",
        "centerRestore",
        "centerOn",
        "zoom",
        "ratio",
        "handScroll",
        "dx",
        "dy",
        "previousScene",
        "nextScene",
        "firstScene",
        "lastScene",
        "downloadURL",
        "QUrl",
        "url",
        "contentSourceUrl",
        "pPos",
        "QSize",
        "pSize",
        "isBackground",
        "internalData",
        "downloadFinished",
        "UBItem*",
        "pSuccess",
        "sourceUrl",
        "contentUrl",
        "pHeader",
        "pData",
        "changeBackground",
        "isDark",
        "UBPageBackground",
        "pageBackground",
        "setToolCursor",
        "tool",
        "showMessage",
        "message",
        "showSpinningWheel",
        "hideMessage",
        "setDisabled",
        "disable",
        "setColorIndex",
        "pColorIndex",
        "removeTool",
        "UBToolWidget*",
        "toolWidget",
        "hide",
        "setWidePageSize",
        "setRegularPageSize",
        "stylusToolChanged",
        "grabScene",
        "QRectF",
        "pSceneRect",
        "addVideo",
        "UBGraphicsMediaItem*",
        "pUrl",
        "startPlay",
        "pos",
        "bUseSource",
        "addAudio",
        "addW3cWidget",
        "UBGraphicsWidgetItem*",
        "adjustDisplayViews",
        "cut",
        "copy",
        "paste",
        "processMimeData",
        "const QMimeData*",
        "pMimeData",
        "moveGraphicsWidgetToControlView",
        "graphicWidget",
        "moveToolWidgetToScene",
        "addItem",
        "freezeW3CWidgets",
        "freeze",
        "freezeW3CWidget",
        "QGraphicsItem*",
        "item",
        "startScript",
        "stopScript",
        "saveData",
        "SaveFlags",
        "fls",
        "documentSceneDuplicated",
        "documentSceneMoved",
        "fromIndex",
        "toIndex",
        "documentSceneDeleted",
        "selectionChanged",
        "undoRedoStateChange",
        "canUndo",
        "documentSceneChanged",
        "pIndex",
        "autosaveTimeout",
        "appMainModeChanged",
        "UBApplicationController::MainMode",
        "stylusToolDoubleClicked",
        "boardViewResized",
        "QResizeEvent*",
        "event",
        "updateBackgroundActionsState",
        "colorPaletteChanged",
        "libraryDialogClosed",
        "ret",
        "lastWindowClosed",
        "onDownloadModalFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newPageAdded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeSceneChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void(qreal)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 5 },
        }}),
        // Signal 'penColorChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'controlViewportChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cacheEnabled'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentReorganized'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'displayMetadata'
        QtMocHelpers::SignalData<void(QMap<QString,QString>)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'pageSelectionChanged'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'npapiWidgetCreated'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'showDocumentsDialog'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showKeyboard'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'togglePodcast'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'blackout'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addScene'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addScene'
        QtMocHelpers::SlotData<void(std::shared_ptr<UBDocumentProxy>, int, bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::Int, 27 }, { QMetaType::Bool, 28 },
        }}),
        // Slot 'addScene'
        QtMocHelpers::SlotData<void(std::shared_ptr<UBDocumentProxy>, int)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::Int, 27 },
        }}),
        // Slot 'addScene'
        QtMocHelpers::SlotData<void(std::shared_ptr<UBGraphicsScene>, bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 }, { QMetaType::Bool, 28 },
        }}),
        // Slot 'addScene'
        QtMocHelpers::SlotData<void(std::shared_ptr<UBGraphicsScene>)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'duplicateScene'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'importPage'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearScene'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSceneItems'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSceneAnnotation'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSceneBackground'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void(QPointF)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void(QPointF)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoomRestore'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'centerRestore'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(QPointF) const>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void() const>(43, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoom'
        QtMocHelpers::SlotData<void(const qreal, QPointF)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 45 }, { 0x80000000 | 38, 39 },
        }}),
        // Slot 'handScroll'
        QtMocHelpers::SlotData<void(qreal, qreal)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 47 }, { QMetaType::QReal, 48 },
        }}),
        // Slot 'previousScene'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextScene'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'firstScene'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'lastScene'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'downloadURL'
        QtMocHelpers::SlotData<void(const QUrl &, QString, const QPointF &, const QSize &, bool, bool)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 }, { QMetaType::QString, 56 }, { 0x80000000 | 38, 57 }, { 0x80000000 | 58, 59 },
            { QMetaType::Bool, 60 }, { QMetaType::Bool, 61 },
        }}),
        // Slot 'downloadURL'
        QtMocHelpers::SlotData<void(const QUrl &, QString, const QPointF &, const QSize &, bool)>(53, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 54, 55 }, { QMetaType::QString, 56 }, { 0x80000000 | 38, 57 }, { 0x80000000 | 58, 59 },
            { QMetaType::Bool, 60 },
        }}),
        // Slot 'downloadURL'
        QtMocHelpers::SlotData<void(const QUrl &, QString, const QPointF &, const QSize &)>(53, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 54, 55 }, { QMetaType::QString, 56 }, { 0x80000000 | 38, 57 }, { 0x80000000 | 58, 59 },
        }}),
        // Slot 'downloadURL'
        QtMocHelpers::SlotData<void(const QUrl &, QString, const QPointF &)>(53, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 54, 55 }, { QMetaType::QString, 56 }, { 0x80000000 | 38, 57 },
        }}),
        // Slot 'downloadURL'
        QtMocHelpers::SlotData<void(const QUrl &, QString)>(53, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 54, 55 }, { QMetaType::QString, 56 },
        }}),
        // Slot 'downloadURL'
        QtMocHelpers::SlotData<void(const QUrl &)>(53, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'downloadFinished'
        QtMocHelpers::SlotData<UBItem *(bool, QUrl, QUrl, QString, QByteArray, QPointF, QSize, bool, bool)>(62, 2, QMC::AccessPublic, 0x80000000 | 63, {{
            { QMetaType::Bool, 64 }, { 0x80000000 | 54, 65 }, { 0x80000000 | 54, 66 }, { QMetaType::QString, 67 },
            { QMetaType::QByteArray, 68 }, { 0x80000000 | 38, 57 }, { 0x80000000 | 58, 59 }, { QMetaType::Bool, 60 },
            { QMetaType::Bool, 61 },
        }}),
        // Slot 'downloadFinished'
        QtMocHelpers::SlotData<UBItem *(bool, QUrl, QUrl, QString, QByteArray, QPointF, QSize, bool)>(62, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 63, {{
            { QMetaType::Bool, 64 }, { 0x80000000 | 54, 65 }, { 0x80000000 | 54, 66 }, { QMetaType::QString, 67 },
            { QMetaType::QByteArray, 68 }, { 0x80000000 | 38, 57 }, { 0x80000000 | 58, 59 }, { QMetaType::Bool, 60 },
        }}),
        // Slot 'downloadFinished'
        QtMocHelpers::SlotData<UBItem *(bool, QUrl, QUrl, QString, QByteArray, QPointF, QSize)>(62, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 63, {{
            { QMetaType::Bool, 64 }, { 0x80000000 | 54, 65 }, { 0x80000000 | 54, 66 }, { QMetaType::QString, 67 },
            { QMetaType::QByteArray, 68 }, { 0x80000000 | 38, 57 }, { 0x80000000 | 58, 59 },
        }}),
        // Slot 'changeBackground'
        QtMocHelpers::SlotData<void(bool, UBPageBackground)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 70 }, { 0x80000000 | 71, 72 },
        }}),
        // Slot 'setToolCursor'
        QtMocHelpers::SlotData<void(int)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 74 },
        }}),
        // Slot 'showMessage'
        QtMocHelpers::SlotData<void(const QString &, bool)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 76 }, { QMetaType::Bool, 77 },
        }}),
        // Slot 'showMessage'
        QtMocHelpers::SlotData<void(const QString &)>(75, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 76 },
        }}),
        // Slot 'hideMessage'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDisabled'
        QtMocHelpers::SlotData<void(bool)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 80 },
        }}),
        // Slot 'setColorIndex'
        QtMocHelpers::SlotData<void(int)>(81, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 82 },
        }}),
        // Slot 'removeTool'
        QtMocHelpers::SlotData<void(UBToolWidget *)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 84, 85 },
        }}),
        // Slot 'hide'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'show'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWidePageSize'
        QtMocHelpers::SlotData<void(bool)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setRegularPageSize'
        QtMocHelpers::SlotData<void(bool)>(88, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'stylusToolChanged'
        QtMocHelpers::SlotData<void(int)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 74 },
        }}),
        // Slot 'grabScene'
        QtMocHelpers::SlotData<void(const QRectF &)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 91, 92 },
        }}),
        // Slot 'addVideo'
        QtMocHelpers::SlotData<UBGraphicsMediaItem *(const QUrl &, bool, const QPointF &, bool)>(93, 2, QMC::AccessPublic, 0x80000000 | 94, {{
            { 0x80000000 | 54, 95 }, { QMetaType::Bool, 96 }, { 0x80000000 | 38, 97 }, { QMetaType::Bool, 98 },
        }}),
        // Slot 'addVideo'
        QtMocHelpers::SlotData<UBGraphicsMediaItem *(const QUrl &, bool, const QPointF &)>(93, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 94, {{
            { 0x80000000 | 54, 95 }, { QMetaType::Bool, 96 }, { 0x80000000 | 38, 97 },
        }}),
        // Slot 'addAudio'
        QtMocHelpers::SlotData<UBGraphicsMediaItem *(const QUrl &, bool, const QPointF &, bool)>(99, 2, QMC::AccessPublic, 0x80000000 | 94, {{
            { 0x80000000 | 54, 95 }, { QMetaType::Bool, 96 }, { 0x80000000 | 38, 97 }, { QMetaType::Bool, 98 },
        }}),
        // Slot 'addAudio'
        QtMocHelpers::SlotData<UBGraphicsMediaItem *(const QUrl &, bool, const QPointF &)>(99, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 94, {{
            { 0x80000000 | 54, 95 }, { QMetaType::Bool, 96 }, { 0x80000000 | 38, 97 },
        }}),
        // Slot 'addW3cWidget'
        QtMocHelpers::SlotData<UBGraphicsWidgetItem *(const QUrl &, const QPointF &)>(100, 2, QMC::AccessPublic, 0x80000000 | 101, {{
            { 0x80000000 | 54, 95 }, { 0x80000000 | 38, 97 },
        }}),
        // Slot 'adjustDisplayViews'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cut'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processMimeData'
        QtMocHelpers::SlotData<void(const QMimeData *, const QPointF &)>(106, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 107, 108 }, { 0x80000000 | 38, 57 },
        }}),
        // Slot 'moveGraphicsWidgetToControlView'
        QtMocHelpers::SlotData<void(UBGraphicsWidgetItem *)>(109, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 101, 110 },
        }}),
        // Slot 'moveToolWidgetToScene'
        QtMocHelpers::SlotData<void(UBToolWidget *)>(111, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 84, 85 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'freezeW3CWidgets'
        QtMocHelpers::SlotData<void(bool)>(113, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 114 },
        }}),
        // Slot 'freezeW3CWidget'
        QtMocHelpers::SlotData<void(QGraphicsItem *, bool)>(115, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 116, 117 }, { QMetaType::Bool, 114 },
        }}),
        // Slot 'startScript'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopScript'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveData'
        QtMocHelpers::SlotData<void(SaveFlags)>(120, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 121, 122 },
        }}),
        // Slot 'saveData'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'documentSceneDuplicated'
        QtMocHelpers::SlotData<void(std::shared_ptr<UBDocumentProxy>, int)>(123, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'documentSceneMoved'
        QtMocHelpers::SlotData<void(std::shared_ptr<UBDocumentProxy>, int, int)>(124, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::Int, 125 }, { QMetaType::Int, 126 },
        }}),
        // Slot 'documentSceneDeleted'
        QtMocHelpers::SlotData<void(std::shared_ptr<UBDocumentProxy>, int)>(127, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void()>(128, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'undoRedoStateChange'
        QtMocHelpers::SlotData<void(bool)>(129, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 130 },
        }}),
        // Slot 'documentSceneChanged'
        QtMocHelpers::SlotData<void(std::shared_ptr<UBDocumentProxy>, int)>(131, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::Int, 132 },
        }}),
        // Slot 'autosaveTimeout'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'appMainModeChanged'
        QtMocHelpers::SlotData<void(UBApplicationController::MainMode)>(134, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 135, 2 },
        }}),
        // Slot 'stylusToolDoubleClicked'
        QtMocHelpers::SlotData<void(int)>(136, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 74 },
        }}),
        // Slot 'boardViewResized'
        QtMocHelpers::SlotData<void(QResizeEvent *)>(137, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 138, 139 },
        }}),
        // Slot 'updateBackgroundActionsState'
        QtMocHelpers::SlotData<void(bool, UBPageBackground)>(140, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 70 }, { 0x80000000 | 71, 72 },
        }}),
        // Slot 'colorPaletteChanged'
        QtMocHelpers::SlotData<void()>(141, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'libraryDialogClosed'
        QtMocHelpers::SlotData<void(int)>(142, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 143 },
        }}),
        // Slot 'lastWindowClosed'
        QtMocHelpers::SlotData<void()>(144, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDownloadModalFinished'
        QtMocHelpers::SlotData<void()>(145, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBBoardController, qt_meta_tag_ZN17UBBoardControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBBoardController::staticMetaObject = { {
    QMetaObject::SuperData::link<UBDocumentContainer::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UBBoardControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UBBoardControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17UBBoardControllerE_t>.metaTypes,
    nullptr
} };

void UBBoardController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBBoardController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newPageAdded(); break;
        case 1: _t->activeSceneChanged(); break;
        case 2: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 3: _t->penColorChanged(); break;
        case 4: _t->controlViewportChanged(); break;
        case 5: _t->backgroundChanged(); break;
        case 6: _t->cacheEnabled(); break;
        case 7: _t->documentReorganized((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->displayMetadata((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 9: _t->pageSelectionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->npapiWidgetCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->showDocumentsDialog(); break;
        case 12: _t->showKeyboard((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->togglePodcast((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->blackout(); break;
        case 15: _t->addScene(); break;
        case 16: _t->addScene((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 17: _t->addScene((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 18: _t->addScene((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBGraphicsScene>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 19: _t->addScene((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBGraphicsScene>>>(_a[1]))); break;
        case 20: _t->duplicateScene(); break;
        case 21: _t->importPage(); break;
        case 22: _t->clearScene(); break;
        case 23: _t->clearSceneItems(); break;
        case 24: _t->clearSceneAnnotation(); break;
        case 25: _t->clearSceneBackground(); break;
        case 26: _t->zoomIn((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 27: _t->zoomIn(); break;
        case 28: _t->zoomOut((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 29: _t->zoomOut(); break;
        case 30: _t->zoomRestore(); break;
        case 31: _t->centerRestore(); break;
        case 32: _t->centerOn((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 33: _t->centerOn(); break;
        case 34: _t->zoom((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 35: _t->handScroll((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 36: _t->previousScene(); break;
        case 37: _t->nextScene(); break;
        case 38: _t->firstScene(); break;
        case 39: _t->lastScene(); break;
        case 40: _t->downloadURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 41: _t->downloadURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 42: _t->downloadURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[4]))); break;
        case 43: _t->downloadURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3]))); break;
        case 44: _t->downloadURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 45: _t->downloadURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 46: { UBItem* _r = _t->downloadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[9])));
            if (_a[0]) *reinterpret_cast<UBItem**>(_a[0]) = std::move(_r); }  break;
        case 47: { UBItem* _r = _t->downloadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])));
            if (_a[0]) *reinterpret_cast<UBItem**>(_a[0]) = std::move(_r); }  break;
        case 48: { UBItem* _r = _t->downloadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[7])));
            if (_a[0]) *reinterpret_cast<UBItem**>(_a[0]) = std::move(_r); }  break;
        case 49: _t->changeBackground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<UBPageBackground>>(_a[2]))); break;
        case 50: _t->setToolCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: _t->showMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 52: _t->showMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 53: _t->hideMessage(); break;
        case 54: _t->setDisabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 55: _t->setColorIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 56: _t->removeTool((*reinterpret_cast<std::add_pointer_t<UBToolWidget*>>(_a[1]))); break;
        case 57: _t->hide(); break;
        case 58: _t->show(); break;
        case 59: _t->setWidePageSize((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 60: _t->setRegularPageSize((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 61: _t->stylusToolChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 62: _t->grabScene((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 63: { UBGraphicsMediaItem* _r = _t->addVideo((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<UBGraphicsMediaItem**>(_a[0]) = std::move(_r); }  break;
        case 64: { UBGraphicsMediaItem* _r = _t->addVideo((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])));
            if (_a[0]) *reinterpret_cast<UBGraphicsMediaItem**>(_a[0]) = std::move(_r); }  break;
        case 65: { UBGraphicsMediaItem* _r = _t->addAudio((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<UBGraphicsMediaItem**>(_a[0]) = std::move(_r); }  break;
        case 66: { UBGraphicsMediaItem* _r = _t->addAudio((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])));
            if (_a[0]) *reinterpret_cast<UBGraphicsMediaItem**>(_a[0]) = std::move(_r); }  break;
        case 67: { UBGraphicsWidgetItem* _r = _t->addW3cWidget((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<UBGraphicsWidgetItem**>(_a[0]) = std::move(_r); }  break;
        case 68: _t->adjustDisplayViews(); break;
        case 69: _t->cut(); break;
        case 70: _t->copy(); break;
        case 71: _t->paste(); break;
        case 72: _t->processMimeData((*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 73: _t->moveGraphicsWidgetToControlView((*reinterpret_cast<std::add_pointer_t<UBGraphicsWidgetItem*>>(_a[1]))); break;
        case 74: _t->moveToolWidgetToScene((*reinterpret_cast<std::add_pointer_t<UBToolWidget*>>(_a[1]))); break;
        case 75: _t->addItem(); break;
        case 76: _t->freezeW3CWidgets((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 77: _t->freezeW3CWidget((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 78: _t->startScript(); break;
        case 79: _t->stopScript(); break;
        case 80: _t->saveData((*reinterpret_cast<std::add_pointer_t<SaveFlags>>(_a[1]))); break;
        case 81: _t->saveData(); break;
        case 82: _t->documentSceneDuplicated((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 83: _t->documentSceneMoved((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 84: _t->documentSceneDeleted((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 85: _t->selectionChanged(); break;
        case 86: _t->undoRedoStateChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 87: _t->documentSceneChanged((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 88: _t->autosaveTimeout(); break;
        case 89: _t->appMainModeChanged((*reinterpret_cast<std::add_pointer_t<UBApplicationController::MainMode>>(_a[1]))); break;
        case 90: _t->stylusToolDoubleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 91: _t->boardViewResized((*reinterpret_cast<std::add_pointer_t<QResizeEvent*>>(_a[1]))); break;
        case 92: _t->updateBackgroundActionsState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<UBPageBackground>>(_a[2]))); break;
        case 93: _t->colorPaletteChanged(); break;
        case 94: _t->libraryDialogClosed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 95: _t->lastWindowClosed(); break;
        case 96: _t->onDownloadModalFinished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 77:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)()>(_a, &UBBoardController::newPageAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)()>(_a, &UBBoardController::activeSceneChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)(qreal )>(_a, &UBBoardController::zoomChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)()>(_a, &UBBoardController::penColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)()>(_a, &UBBoardController::controlViewportChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)()>(_a, &UBBoardController::backgroundChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)()>(_a, &UBBoardController::cacheEnabled, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)(int )>(_a, &UBBoardController::documentReorganized, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)(QMap<QString,QString> )>(_a, &UBBoardController::displayMetadata, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)(int )>(_a, &UBBoardController::pageSelectionChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardController::*)(const QString & )>(_a, &UBBoardController::npapiWidgetCreated, 10))
            return;
    }
}

const QMetaObject *UBBoardController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBBoardController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UBBoardControllerE_t>.strings))
        return static_cast<void*>(this);
    return UBDocumentContainer::qt_metacast(_clname);
}

int UBBoardController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBDocumentContainer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 97)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 97;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 97)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 97;
    }
    return _id;
}

// SIGNAL 0
void UBBoardController::newPageAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UBBoardController::activeSceneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UBBoardController::zoomChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UBBoardController::penColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void UBBoardController::controlViewportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void UBBoardController::backgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void UBBoardController::cacheEnabled()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void UBBoardController::documentReorganized(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void UBBoardController::displayMetadata(QMap<QString,QString> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void UBBoardController::pageSelectionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void UBBoardController::npapiWidgetCreated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
