/****************************************************************************
** Meta object code from reading C++ file 'UBBoardPaletteManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/board/UBBoardPaletteManager.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBBoardPaletteManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21UBBoardPaletteManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto UBBoardPaletteManager::qt_create_metaobjectdata<qt_meta_tag_ZN21UBBoardPaletteManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBBoardPaletteManager",
        "activeSceneChanged",
        "",
        "containerResized",
        "addItem",
        "QUrl",
        "pUrl",
        "QPixmap",
        "pPixmap",
        "QPointF",
        "p",
        "scale",
        "sourceUrl",
        "slot_changeMainMode",
        "UBApplicationController::MainMode",
        "slot_changeDesktopMode",
        "toggleErasePalette",
        "ckecked",
        "changeBackground",
        "toggleBackgroundPalette",
        "checked",
        "backgroundPaletteClosed",
        "toggleStylusPalette",
        "tooglePodcastPalette",
        "erasePaletteButtonPressed",
        "erasePaletteButtonReleased",
        "erasePaletteClosed",
        "togglePagePalette",
        "pagePaletteClosed",
        "pagePaletteButtonPressed",
        "pagePaletteButtonReleased",
        "addItemToCurrentPage",
        "addItemToNewPage",
        "addItemToLibrary",
        "purchaseLinkActivated",
        "linkClicked",
        "url",
        "zoomButtonPressed",
        "zoomButtonReleased",
        "handButtonPressed",
        "handButtonReleased",
        "changeStylusPaletteOrientation",
        "QVariant",
        "var"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'activeSceneChanged'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'containerResized'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(const QUrl &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(const QPixmap &, const QPointF &, qreal, const QUrl &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { QMetaType::QReal, 11 }, { 0x80000000 | 5, 12 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(const QPixmap &, const QPointF &, qreal)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { QMetaType::QReal, 11 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(const QPixmap &, const QPointF &)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(const QPixmap &)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'slot_changeMainMode'
        QtMocHelpers::SlotData<void(UBApplicationController::MainMode)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'slot_changeDesktopMode'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleErasePalette'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'changeBackground'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleBackgroundPalette'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'backgroundPaletteClosed'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleStylusPalette'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'tooglePodcastPalette'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'erasePaletteButtonPressed'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'erasePaletteButtonReleased'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'erasePaletteClosed'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'togglePagePalette'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'pagePaletteClosed'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pagePaletteButtonPressed'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pagePaletteButtonReleased'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addItemToCurrentPage'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addItemToNewPage'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addItemToLibrary'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'purchaseLinkActivated'
        QtMocHelpers::SlotData<void(const QString &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'linkClicked'
        QtMocHelpers::SlotData<void(const QUrl &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 36 },
        }}),
        // Slot 'zoomButtonPressed'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomButtonReleased'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handButtonPressed'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handButtonReleased'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeStylusPaletteOrientation'
        QtMocHelpers::SlotData<void(QVariant)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBBoardPaletteManager, qt_meta_tag_ZN21UBBoardPaletteManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBBoardPaletteManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UBBoardPaletteManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UBBoardPaletteManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21UBBoardPaletteManagerE_t>.metaTypes,
    nullptr
} };

void UBBoardPaletteManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBBoardPaletteManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeSceneChanged(); break;
        case 1: _t->containerResized(); break;
        case 2: _t->addItem((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->addItem((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[4]))); break;
        case 4: _t->addItem((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3]))); break;
        case 5: _t->addItem((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 6: _t->addItem((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1]))); break;
        case 7: _t->slot_changeMainMode((*reinterpret_cast<std::add_pointer_t<UBApplicationController::MainMode>>(_a[1]))); break;
        case 8: _t->slot_changeDesktopMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->toggleErasePalette((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->changeBackground(); break;
        case 11: _t->toggleBackgroundPalette((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->backgroundPaletteClosed(); break;
        case 13: _t->toggleStylusPalette((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->tooglePodcastPalette((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->erasePaletteButtonPressed(); break;
        case 16: _t->erasePaletteButtonReleased(); break;
        case 17: _t->erasePaletteClosed(); break;
        case 18: _t->togglePagePalette((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->pagePaletteClosed(); break;
        case 20: _t->pagePaletteButtonPressed(); break;
        case 21: _t->pagePaletteButtonReleased(); break;
        case 22: _t->addItemToCurrentPage(); break;
        case 23: _t->addItemToNewPage(); break;
        case 24: _t->addItemToLibrary(); break;
        case 25: _t->purchaseLinkActivated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->linkClicked((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 27: _t->zoomButtonPressed(); break;
        case 28: _t->zoomButtonReleased(); break;
        case 29: _t->handButtonPressed(); break;
        case 30: _t->handButtonReleased(); break;
        case 31: _t->changeStylusPaletteOrientation((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *UBBoardPaletteManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBBoardPaletteManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UBBoardPaletteManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBBoardPaletteManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}
QT_WARNING_POP
