/****************************************************************************
** Meta object code from reading C++ file 'tabwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/web/simplebrowser/tabwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9TabWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto TabWidget::qt_create_metaobjectdata<qt_meta_tag_ZN9TabWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TabWidget",
        "linkHovered",
        "",
        "link",
        "loadProgress",
        "progress",
        "titleChanged",
        "title",
        "urlChanged",
        "QUrl",
        "url",
        "favIconChanged",
        "QIcon",
        "icon",
        "webActionEnabledChanged",
        "QWebEnginePage::WebAction",
        "action",
        "enabled",
        "devToolsRequested",
        "QWebEnginePage*",
        "source",
        "tabCreated",
        "WebView*",
        "webView",
        "tabClosing",
        "setUrl",
        "triggerWebPageAction",
        "createTab",
        "createBackgroundTab",
        "closeTab",
        "index",
        "nextTab",
        "previousTab",
        "handleCurrentChanged",
        "handleContextMenuRequested",
        "QPoint",
        "pos",
        "cloneTab",
        "closeOtherTabs",
        "reloadAllTabs",
        "reloadTab"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'linkHovered'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'loadProgress'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'favIconChanged'
        QtMocHelpers::SignalData<void(const QIcon &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'webActionEnabledChanged'
        QtMocHelpers::SignalData<void(QWebEnginePage::WebAction, bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'devToolsRequested'
        QtMocHelpers::SignalData<void(QWebEnginePage *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'tabCreated'
        QtMocHelpers::SignalData<void(WebView *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'tabClosing'
        QtMocHelpers::SignalData<void(WebView *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'setUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'triggerWebPageAction'
        QtMocHelpers::SlotData<void(QWebEnginePage::WebAction)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'createTab'
        QtMocHelpers::SlotData<WebView *()>(27, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'createBackgroundTab'
        QtMocHelpers::SlotData<WebView *()>(28, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'closeTab'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'nextTab'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previousTab'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleCurrentChanged'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'handleContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'cloneTab'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'closeOtherTabs'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'reloadAllTabs'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadTab'
        QtMocHelpers::SlotData<void(int)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabWidget, qt_meta_tag_ZN9TabWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TabWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QTabWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TabWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TabWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9TabWidgetE_t>.metaTypes,
    nullptr
} };

void TabWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->linkHovered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->loadProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->favIconChanged((*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[1]))); break;
        case 5: _t->webActionEnabledChanged((*reinterpret_cast<std::add_pointer_t<QWebEnginePage::WebAction>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->devToolsRequested((*reinterpret_cast<std::add_pointer_t<QWebEnginePage*>>(_a[1]))); break;
        case 7: _t->tabCreated((*reinterpret_cast<std::add_pointer_t<WebView*>>(_a[1]))); break;
        case 8: _t->tabClosing((*reinterpret_cast<std::add_pointer_t<WebView*>>(_a[1]))); break;
        case 9: _t->setUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->triggerWebPageAction((*reinterpret_cast<std::add_pointer_t<QWebEnginePage::WebAction>>(_a[1]))); break;
        case 11: { WebView* _r = _t->createTab();
            if (_a[0]) *reinterpret_cast<WebView**>(_a[0]) = std::move(_r); }  break;
        case 12: { WebView* _r = _t->createBackgroundTab();
            if (_a[0]) *reinterpret_cast<WebView**>(_a[0]) = std::move(_r); }  break;
        case 13: _t->closeTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->nextTab(); break;
        case 15: _t->previousTab(); break;
        case 16: _t->handleCurrentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->handleContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 18: _t->cloneTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->closeOtherTabs((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->reloadAllTabs(); break;
        case 21: _t->reloadTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWebEnginePage* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(const QString & )>(_a, &TabWidget::linkHovered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(int )>(_a, &TabWidget::loadProgress, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(const QString & )>(_a, &TabWidget::titleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(const QUrl & )>(_a, &TabWidget::urlChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(const QIcon & )>(_a, &TabWidget::favIconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(QWebEnginePage::WebAction , bool )>(_a, &TabWidget::webActionEnabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(QWebEnginePage * )>(_a, &TabWidget::devToolsRequested, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(WebView * )>(_a, &TabWidget::tabCreated, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(WebView * )>(_a, &TabWidget::tabClosing, 8))
            return;
    }
}

const QMetaObject *TabWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TabWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int TabWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void TabWidget::linkHovered(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TabWidget::loadProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TabWidget::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TabWidget::urlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void TabWidget::favIconChanged(const QIcon & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void TabWidget::webActionEnabledChanged(QWebEnginePage::WebAction _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void TabWidget::devToolsRequested(QWebEnginePage * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void TabWidget::tabCreated(WebView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void TabWidget::tabClosing(WebView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
