/****************************************************************************
** Meta object code from reading C++ file 'UBGraphicsWidgetItem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/domain/UBGraphicsWidgetItem.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBGraphicsWidgetItem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20UBGraphicsWidgetItemE_t {};
} // unnamed namespace

template <> constexpr inline auto UBGraphicsWidgetItem::qt_create_metaobjectdata<qt_meta_tag_ZN20UBGraphicsWidgetItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBGraphicsWidgetItem",
        "initAPI",
        "",
        "freeze",
        "unFreeze",
        "setWebActive",
        "active",
        "inspectPage",
        "closeInspector",
        "geometryChangeRequested",
        "QRect",
        "geom",
        "registerAPI",
        "mainFrameLoadFinished",
        "ok"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'initAPI'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'freeze'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unFreeze'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWebActive'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'inspectPage'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeInspector'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'geometryChangeRequested'
        QtMocHelpers::SlotData<void(const QRect &)>(9, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'registerAPI'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'mainFrameLoadFinished'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBGraphicsWidgetItem, qt_meta_tag_ZN20UBGraphicsWidgetItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBGraphicsWidgetItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsProxyWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20UBGraphicsWidgetItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20UBGraphicsWidgetItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20UBGraphicsWidgetItemE_t>.metaTypes,
    nullptr
} };

void UBGraphicsWidgetItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBGraphicsWidgetItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initAPI(); break;
        case 1: _t->freeze(); break;
        case 2: _t->unFreeze(); break;
        case 3: _t->setWebActive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->inspectPage(); break;
        case 5: _t->closeInspector(); break;
        case 6: _t->geometryChangeRequested((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 7: _t->registerAPI(); break;
        case 8: _t->mainFrameLoadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *UBGraphicsWidgetItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBGraphicsWidgetItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20UBGraphicsWidgetItemE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "UBItem"))
        return static_cast< UBItem*>(this);
    if (!strcmp(_clname, "UBResizableGraphicsItem"))
        return static_cast< UBResizableGraphicsItem*>(this);
    if (!strcmp(_clname, "UBGraphicsItem"))
        return static_cast< UBGraphicsItem*>(this);
    return QGraphicsProxyWidget::qt_metacast(_clname);
}

int UBGraphicsWidgetItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsProxyWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN25UBGraphicsAppleWidgetItemE_t {};
} // unnamed namespace

template <> constexpr inline auto UBGraphicsAppleWidgetItem::qt_create_metaobjectdata<qt_meta_tag_ZN25UBGraphicsAppleWidgetItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBGraphicsAppleWidgetItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBGraphicsAppleWidgetItem, qt_meta_tag_ZN25UBGraphicsAppleWidgetItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBGraphicsAppleWidgetItem::staticMetaObject = { {
    QMetaObject::SuperData::link<UBGraphicsWidgetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25UBGraphicsAppleWidgetItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25UBGraphicsAppleWidgetItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25UBGraphicsAppleWidgetItemE_t>.metaTypes,
    nullptr
} };

void UBGraphicsAppleWidgetItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBGraphicsAppleWidgetItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UBGraphicsAppleWidgetItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBGraphicsAppleWidgetItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25UBGraphicsAppleWidgetItemE_t>.strings))
        return static_cast<void*>(this);
    return UBGraphicsWidgetItem::qt_metacast(_clname);
}

int UBGraphicsAppleWidgetItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBGraphicsWidgetItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN23UBGraphicsW3CWidgetItemE_t {};
} // unnamed namespace

template <> constexpr inline auto UBGraphicsW3CWidgetItem::qt_create_metaobjectdata<qt_meta_tag_ZN23UBGraphicsW3CWidgetItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBGraphicsW3CWidgetItem",
        "registerAPI",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'registerAPI'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBGraphicsW3CWidgetItem, qt_meta_tag_ZN23UBGraphicsW3CWidgetItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBGraphicsW3CWidgetItem::staticMetaObject = { {
    QMetaObject::SuperData::link<UBGraphicsWidgetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23UBGraphicsW3CWidgetItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23UBGraphicsW3CWidgetItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23UBGraphicsW3CWidgetItemE_t>.metaTypes,
    nullptr
} };

void UBGraphicsW3CWidgetItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBGraphicsW3CWidgetItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->registerAPI(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *UBGraphicsW3CWidgetItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBGraphicsW3CWidgetItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23UBGraphicsW3CWidgetItemE_t>.strings))
        return static_cast<void*>(this);
    return UBGraphicsWidgetItem::qt_metacast(_clname);
}

int UBGraphicsW3CWidgetItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBGraphicsWidgetItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
