/****************************************************************************
** Meta object code from reading C++ file 'UBBoardThumbnailsView.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/gui/UBBoardThumbnailsView.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBBoardThumbnailsView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21UBBoardThumbnailsViewE_t {};
} // unnamed namespace

template <> constexpr inline auto UBBoardThumbnailsView::qt_create_metaobjectdata<qt_meta_tag_ZN21UBBoardThumbnailsViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBBoardThumbnailsView",
        "mousePressAndHoldEventRequired",
        "",
        "QPoint",
        "pos",
        "moveThumbnailRequired",
        "from",
        "to",
        "updateActiveThumbnail",
        "newActiveIndex",
        "ensureVisibleThumbnail",
        "index",
        "centerOnThumbnail",
        "adjustThumbnail",
        "longPressTimeout",
        "mousePressAndHoldEvent",
        "updateThumbnailPixmap",
        "QRectF",
        "region"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mousePressAndHoldEventRequired'
        QtMocHelpers::SignalData<void(QPoint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'moveThumbnailRequired'
        QtMocHelpers::SignalData<void(int, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'updateActiveThumbnail'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'ensureVisibleThumbnail'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'centerOnThumbnail'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'adjustThumbnail'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'longPressTimeout'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mousePressAndHoldEvent'
        QtMocHelpers::SlotData<void(QPoint)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'updateThumbnailPixmap'
        QtMocHelpers::SlotData<void(const QRectF)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBBoardThumbnailsView, qt_meta_tag_ZN21UBBoardThumbnailsViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBBoardThumbnailsView::staticMetaObject = { {
    QMetaObject::SuperData::link<UBThumbnailsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UBBoardThumbnailsViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UBBoardThumbnailsViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21UBBoardThumbnailsViewE_t>.metaTypes,
    nullptr
} };

void UBBoardThumbnailsView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBBoardThumbnailsView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mousePressAndHoldEventRequired((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 1: _t->moveThumbnailRequired((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->updateActiveThumbnail((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->ensureVisibleThumbnail((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->centerOnThumbnail((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->adjustThumbnail(); break;
        case 6: _t->longPressTimeout(); break;
        case 7: _t->mousePressAndHoldEvent((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 8: _t->updateThumbnailPixmap((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBBoardThumbnailsView::*)(QPoint )>(_a, &UBBoardThumbnailsView::mousePressAndHoldEventRequired, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardThumbnailsView::*)(int , int )>(_a, &UBBoardThumbnailsView::moveThumbnailRequired, 1))
            return;
    }
}

const QMetaObject *UBBoardThumbnailsView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBBoardThumbnailsView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UBBoardThumbnailsViewE_t>.strings))
        return static_cast<void*>(this);
    return UBThumbnailsView::qt_metacast(_clname);
}

int UBBoardThumbnailsView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBThumbnailsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void UBBoardThumbnailsView::mousePressAndHoldEventRequired(QPoint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UBBoardThumbnailsView::moveThumbnailRequired(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
