/********************************************************************************
** Form generated from reading UI file 'trapFlash.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRAPFLASH_H
#define UI_TRAPFLASH_H

#include <QtCore/QVariant>
#include <QtWebEngineWidgets/QWebEngineView>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_trapFlashDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *selectFlashLabel;
    QComboBox *flashCombobox;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QHBoxLayout *horizontalLayout_2;
    QWebEngineView *webView;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QLineEdit *widgetNameLineEdit;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer;
    QPushButton *createWidgetButton;

    void setupUi(QDialog *trapFlashDialog)
    {
        if (trapFlashDialog->objectName().isEmpty())
            trapFlashDialog->setObjectName("trapFlashDialog");
        trapFlashDialog->resize(508, 417);
        verticalLayout = new QVBoxLayout(trapFlashDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        selectFlashLabel = new QLabel(trapFlashDialog);
        selectFlashLabel->setObjectName("selectFlashLabel");

        horizontalLayout_3->addWidget(selectFlashLabel);

        flashCombobox = new QComboBox(trapFlashDialog);
        flashCombobox->setObjectName("flashCombobox");

        horizontalLayout_3->addWidget(flashCombobox);

        horizontalLayout_3->setStretch(1, 1);

        verticalLayout->addLayout(horizontalLayout_3);

        scrollArea = new QScrollArea(trapFlashDialog);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 488, 298));
        horizontalLayout_2 = new QHBoxLayout(scrollAreaWidgetContents);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        webView = new QWebEngineView(scrollAreaWidgetContents);
        webView->setObjectName("webView");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(webView->sizePolicy().hasHeightForWidth());
        webView->setSizePolicy(sizePolicy);
        webView->setProperty("url", QVariant(QUrl(QString::fromUtf8("about:blank"))));

        horizontalLayout_2->addWidget(webView);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout->addWidget(scrollArea);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(trapFlashDialog);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);


        horizontalLayout->addLayout(verticalLayout_2);

        widgetNameLineEdit = new QLineEdit(trapFlashDialog);
        widgetNameLineEdit->setObjectName("widgetNameLineEdit");

        horizontalLayout->addWidget(widgetNameLineEdit);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);

        createWidgetButton = new QPushButton(trapFlashDialog);
        createWidgetButton->setObjectName("createWidgetButton");

        horizontalLayout_4->addWidget(createWidgetButton);


        verticalLayout->addLayout(horizontalLayout_4);


        retranslateUi(trapFlashDialog);

        QMetaObject::connectSlotsByName(trapFlashDialog);
    } // setupUi

    void retranslateUi(QDialog *trapFlashDialog)
    {
        trapFlashDialog->setWindowTitle(QCoreApplication::translate("trapFlashDialog", "Capture Web Content", nullptr));
        selectFlashLabel->setText(QCoreApplication::translate("trapFlashDialog", "Select a content to capture", nullptr));
        label->setText(QCoreApplication::translate("trapFlashDialog", "Application name", nullptr));
        createWidgetButton->setText(QCoreApplication::translate("trapFlashDialog", "Create Application", nullptr));
    } // retranslateUi

};

namespace Ui {
    class trapFlashDialog: public Ui_trapFlashDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TRAPFLASH_H
