/****************************************************************************
** Meta object code from reading C++ file 'UBGraphicsScene.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/domain/UBGraphicsScene.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBGraphicsScene.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18UBZLayerControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto UBZLayerController::qt_create_metaobjectdata<qt_meta_tag_ZN18UBZLayerControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBZLayerController"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBZLayerController, qt_meta_tag_ZN18UBZLayerControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBZLayerController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UBZLayerControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UBZLayerControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18UBZLayerControllerE_t>.metaTypes,
    nullptr
} };

void UBZLayerController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBZLayerController *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UBZLayerController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBZLayerController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UBZLayerControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBZLayerController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN15UBGraphicsSceneE_t {};
} // unnamed namespace

template <> constexpr inline auto UBGraphicsScene::qt_create_metaobjectdata<qt_meta_tag_ZN15UBGraphicsSceneE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBGraphicsScene",
        "zoomChanged",
        "",
        "zoomFactor",
        "updateSelectionFrame",
        "updateSelectionFrameWrapper",
        "initStroke",
        "hideTool",
        "setBackground",
        "pIsDark",
        "UBPageBackground",
        "pBackground",
        "setBackgroundZoomFactor",
        "zoom",
        "setBackgroundGridSize",
        "pSize",
        "setIntermediateLines",
        "checked",
        "setDrawingMode",
        "bModeDesktop",
        "deselectAllItems",
        "addPixmap",
        "UBGraphicsPixmapItem*",
        "QPixmap",
        "pPixmap",
        "QGraphicsItem*",
        "replaceFor",
        "QPointF",
        "pPos",
        "scaleFactor",
        "pUseAnimation",
        "useProxyForDocumentPath",
        "addImage",
        "pData",
        "textUndoCommandAdded",
        "UBGraphicsTextItem*",
        "textItem",
        "setToolCursor",
        "tool",
        "selectionChangedProcessing",
        "moveMagnifier",
        "QPoint",
        "newPos",
        "forceGrab",
        "closeMagnifier",
        "zoomInMagnifier",
        "zoomOutMagnifier",
        "changeMagnifierMode",
        "mode",
        "resizedMagnifier",
        "newPercent",
        "stylusToolChanged",
        "previousTool",
        "controlViewportChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void(qreal)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 3 },
        }}),
        // Slot 'updateSelectionFrame'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateSelectionFrameWrapper'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'initStroke'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hideTool'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBackground'
        QtMocHelpers::SlotData<void(bool, UBPageBackground)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'setBackgroundZoomFactor'
        QtMocHelpers::SlotData<void(qreal)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 13 },
        }}),
        // Slot 'setBackgroundGridSize'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setIntermediateLines'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'setDrawingMode'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'deselectAllItems'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addPixmap'
        QtMocHelpers::SlotData<UBGraphicsPixmapItem *(const QPixmap &, QGraphicsItem *, const QPointF &, qreal, bool, bool)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 }, { QMetaType::QReal, 29 },
            { QMetaType::Bool, 30 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'addPixmap'
        QtMocHelpers::SlotData<UBGraphicsPixmapItem *(const QPixmap &, QGraphicsItem *, const QPointF &, qreal, bool)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 }, { QMetaType::QReal, 29 },
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'addPixmap'
        QtMocHelpers::SlotData<UBGraphicsPixmapItem *(const QPixmap &, QGraphicsItem *, const QPointF &, qreal)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 }, { QMetaType::QReal, 29 },
        }}),
        // Slot 'addPixmap'
        QtMocHelpers::SlotData<UBGraphicsPixmapItem *(const QPixmap &, QGraphicsItem *, const QPointF &)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 },
        }}),
        // Slot 'addPixmap'
        QtMocHelpers::SlotData<UBGraphicsPixmapItem *(const QPixmap &, QGraphicsItem *)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'addImage'
        QtMocHelpers::SlotData<UBGraphicsPixmapItem *(QByteArray, QGraphicsItem *, const QPointF &, qreal, bool, bool)>(32, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QByteArray, 33 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 }, { QMetaType::QReal, 29 },
            { QMetaType::Bool, 30 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'addImage'
        QtMocHelpers::SlotData<UBGraphicsPixmapItem *(QByteArray, QGraphicsItem *, const QPointF &, qreal, bool)>(32, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22, {{
            { QMetaType::QByteArray, 33 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 }, { QMetaType::QReal, 29 },
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'addImage'
        QtMocHelpers::SlotData<UBGraphicsPixmapItem *(QByteArray, QGraphicsItem *, const QPointF &, qreal)>(32, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22, {{
            { QMetaType::QByteArray, 33 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 }, { QMetaType::QReal, 29 },
        }}),
        // Slot 'addImage'
        QtMocHelpers::SlotData<UBGraphicsPixmapItem *(QByteArray, QGraphicsItem *, const QPointF &)>(32, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22, {{
            { QMetaType::QByteArray, 33 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 },
        }}),
        // Slot 'addImage'
        QtMocHelpers::SlotData<UBGraphicsPixmapItem *(QByteArray, QGraphicsItem *)>(32, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22, {{
            { QMetaType::QByteArray, 33 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'textUndoCommandAdded'
        QtMocHelpers::SlotData<void(UBGraphicsTextItem *)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'setToolCursor'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Slot 'selectionChangedProcessing'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveMagnifier'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveMagnifier'
        QtMocHelpers::SlotData<void(QPoint, bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 }, { QMetaType::Bool, 43 },
        }}),
        // Slot 'moveMagnifier'
        QtMocHelpers::SlotData<void(QPoint)>(40, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'closeMagnifier'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomInMagnifier'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOutMagnifier'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeMagnifierMode'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'resizedMagnifier'
        QtMocHelpers::SlotData<void(qreal)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 50 },
        }}),
        // Slot 'stylusToolChanged'
        QtMocHelpers::SlotData<void(int, int)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 38 }, { QMetaType::Int, 52 },
        }}),
        // Slot 'controlViewportChanged'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBGraphicsScene, qt_meta_tag_ZN15UBGraphicsSceneE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBGraphicsScene::staticMetaObject = { {
    QMetaObject::SuperData::link<UBCoreGraphicsScene::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15UBGraphicsSceneE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15UBGraphicsSceneE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15UBGraphicsSceneE_t>.metaTypes,
    nullptr
} };

void UBGraphicsScene::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBGraphicsScene *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 1: _t->updateSelectionFrame(); break;
        case 2: _t->updateSelectionFrameWrapper((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->initStroke(); break;
        case 4: _t->hideTool(); break;
        case 5: _t->setBackground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<UBPageBackground>>(_a[2]))); break;
        case 6: _t->setBackgroundZoomFactor((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 7: _t->setBackgroundGridSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setIntermediateLines((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setDrawingMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->deselectAllItems(); break;
        case 11: { UBGraphicsPixmapItem* _r = _t->addPixmap((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<UBGraphicsPixmapItem**>(_a[0]) = std::move(_r); }  break;
        case 12: { UBGraphicsPixmapItem* _r = _t->addPixmap((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<UBGraphicsPixmapItem**>(_a[0]) = std::move(_r); }  break;
        case 13: { UBGraphicsPixmapItem* _r = _t->addPixmap((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])));
            if (_a[0]) *reinterpret_cast<UBGraphicsPixmapItem**>(_a[0]) = std::move(_r); }  break;
        case 14: { UBGraphicsPixmapItem* _r = _t->addPixmap((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])));
            if (_a[0]) *reinterpret_cast<UBGraphicsPixmapItem**>(_a[0]) = std::move(_r); }  break;
        case 15: { UBGraphicsPixmapItem* _r = _t->addPixmap((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<UBGraphicsPixmapItem**>(_a[0]) = std::move(_r); }  break;
        case 16: { UBGraphicsPixmapItem* _r = _t->addImage((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<UBGraphicsPixmapItem**>(_a[0]) = std::move(_r); }  break;
        case 17: { UBGraphicsPixmapItem* _r = _t->addImage((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<UBGraphicsPixmapItem**>(_a[0]) = std::move(_r); }  break;
        case 18: { UBGraphicsPixmapItem* _r = _t->addImage((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])));
            if (_a[0]) *reinterpret_cast<UBGraphicsPixmapItem**>(_a[0]) = std::move(_r); }  break;
        case 19: { UBGraphicsPixmapItem* _r = _t->addImage((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])));
            if (_a[0]) *reinterpret_cast<UBGraphicsPixmapItem**>(_a[0]) = std::move(_r); }  break;
        case 20: { UBGraphicsPixmapItem* _r = _t->addImage((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<UBGraphicsPixmapItem**>(_a[0]) = std::move(_r); }  break;
        case 21: _t->textUndoCommandAdded((*reinterpret_cast<std::add_pointer_t<UBGraphicsTextItem*>>(_a[1]))); break;
        case 22: _t->setToolCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->selectionChangedProcessing(); break;
        case 24: _t->moveMagnifier(); break;
        case 25: _t->moveMagnifier((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 26: _t->moveMagnifier((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 27: _t->closeMagnifier(); break;
        case 28: _t->zoomInMagnifier(); break;
        case 29: _t->zoomOutMagnifier(); break;
        case 30: _t->changeMagnifierMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->resizedMagnifier((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 32: _t->stylusToolChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 33: _t->controlViewportChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBGraphicsScene::*)(qreal )>(_a, &UBGraphicsScene::zoomChanged, 0))
            return;
    }
}

const QMetaObject *UBGraphicsScene::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBGraphicsScene::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15UBGraphicsSceneE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "UBItem"))
        return static_cast< UBItem*>(this);
    if (!strcmp(_clname, "std::enable_shared_from_this<UBGraphicsScene>"))
        return static_cast< std::enable_shared_from_this<UBGraphicsScene>*>(this);
    return UBCoreGraphicsScene::qt_metacast(_clname);
}

int UBGraphicsScene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBCoreGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void UBGraphicsScene::zoomChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
