/****************************************************************************
** Meta object code from reading C++ file 'UBDownloadManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/core/UBDownloadManager.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBDownloadManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18UBDownloadHttpFileE_t {};
} // unnamed namespace

template <> constexpr inline auto UBDownloadHttpFile::qt_create_metaobjectdata<qt_meta_tag_ZN18UBDownloadHttpFileE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBDownloadHttpFile",
        "downloadProgress",
        "",
        "id",
        "current",
        "total",
        "downloadFinished",
        "pSuccess",
        "QUrl",
        "sourceUrl",
        "contentUrl",
        "pContentTypeHeader",
        "pData",
        "QPointF",
        "pPos",
        "QSize",
        "pSize",
        "isBackground",
        "onDownloadFinished",
        "onDownloadProgress",
        "bytesReceived",
        "bytesTotal"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'downloadProgress'
        QtMocHelpers::SignalData<void(int, qint64, qint64)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::LongLong, 4 }, { QMetaType::LongLong, 5 },
        }}),
        // Signal 'downloadFinished'
        QtMocHelpers::SignalData<void(int, bool, QUrl, QUrl, QString, QByteArray, QPointF, QSize, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Bool, 7 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 10 },
            { QMetaType::QString, 11 }, { QMetaType::QByteArray, 12 }, { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 },
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'onDownloadFinished'
        QtMocHelpers::SlotData<void(bool, QUrl, QString, QByteArray, QPointF, QSize, bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QString, 11 }, { QMetaType::QByteArray, 12 },
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Slot 'onDownloadProgress'
        QtMocHelpers::SlotData<void(qint64, qint64)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 20 }, { QMetaType::LongLong, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBDownloadHttpFile, qt_meta_tag_ZN18UBDownloadHttpFileE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBDownloadHttpFile::staticMetaObject = { {
    QMetaObject::SuperData::link<UBHttpGet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UBDownloadHttpFileE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UBDownloadHttpFileE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18UBDownloadHttpFileE_t>.metaTypes,
    nullptr
} };

void UBDownloadHttpFile::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBDownloadHttpFile *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->downloadProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 1: _t->downloadFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[9]))); break;
        case 2: _t->onDownloadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7]))); break;
        case 3: _t->onDownloadProgress((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBDownloadHttpFile::*)(int , qint64 , qint64 )>(_a, &UBDownloadHttpFile::downloadProgress, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDownloadHttpFile::*)(int , bool , QUrl , QUrl , QString , QByteArray , QPointF , QSize , bool )>(_a, &UBDownloadHttpFile::downloadFinished, 1))
            return;
    }
}

const QMetaObject *UBDownloadHttpFile::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBDownloadHttpFile::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UBDownloadHttpFileE_t>.strings))
        return static_cast<void*>(this);
    return UBHttpGet::qt_metacast(_clname);
}

int UBDownloadHttpFile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBHttpGet::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void UBDownloadHttpFile::downloadProgress(int _t1, qint64 _t2, qint64 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void UBDownloadHttpFile::downloadFinished(int _t1, bool _t2, QUrl _t3, QUrl _t4, QString _t5, QByteArray _t6, QPointF _t7, QSize _t8, bool _t9)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8, _t9);
}
namespace {
struct qt_meta_tag_ZN26UBAsyncLocalFileDownloaderE_t {};
} // unnamed namespace

template <> constexpr inline auto UBAsyncLocalFileDownloader::qt_create_metaobjectdata<qt_meta_tag_ZN26UBAsyncLocalFileDownloaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBAsyncLocalFileDownloader",
        "finished",
        "",
        "srcUrl",
        "resUrl",
        "signal_asyncCopyFinished",
        "id",
        "pSuccess",
        "QUrl",
        "sourceUrl",
        "contentUrl",
        "pContentTypeHeader",
        "pData",
        "QPointF",
        "pPos",
        "QSize",
        "pSize",
        "isBackground"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(QString, QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'signal_asyncCopyFinished'
        QtMocHelpers::SignalData<void(int, bool, QUrl, QUrl, QString, QByteArray, QPointF, QSize, bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::Bool, 7 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 10 },
            { QMetaType::QString, 11 }, { QMetaType::QByteArray, 12 }, { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 },
            { QMetaType::Bool, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBAsyncLocalFileDownloader, qt_meta_tag_ZN26UBAsyncLocalFileDownloaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBAsyncLocalFileDownloader::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26UBAsyncLocalFileDownloaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26UBAsyncLocalFileDownloaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26UBAsyncLocalFileDownloaderE_t>.metaTypes,
    nullptr
} };

void UBAsyncLocalFileDownloader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBAsyncLocalFileDownloader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->signal_asyncCopyFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[9]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBAsyncLocalFileDownloader::*)(QString , QString )>(_a, &UBAsyncLocalFileDownloader::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBAsyncLocalFileDownloader::*)(int , bool , QUrl , QUrl , QString , QByteArray , QPointF , QSize , bool )>(_a, &UBAsyncLocalFileDownloader::signal_asyncCopyFinished, 1))
            return;
    }
}

const QMetaObject *UBAsyncLocalFileDownloader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBAsyncLocalFileDownloader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26UBAsyncLocalFileDownloaderE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int UBAsyncLocalFileDownloader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void UBAsyncLocalFileDownloader::finished(QString _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void UBAsyncLocalFileDownloader::signal_asyncCopyFinished(int _t1, bool _t2, QUrl _t3, QUrl _t4, QString _t5, QByteArray _t6, QPointF _t7, QSize _t8, bool _t9)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8, _t9);
}
namespace {
struct qt_meta_tag_ZN17UBDownloadManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto UBDownloadManager::qt_create_metaobjectdata<qt_meta_tag_ZN17UBDownloadManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBDownloadManager",
        "fileAddedToDownload",
        "",
        "downloadUpdated",
        "id",
        "crnt",
        "total",
        "downloadFinished",
        "pSuccess",
        "QUrl",
        "sourceUrl",
        "pContentTypeHeader",
        "pData",
        "sDownloadFileDesc",
        "desc",
        "downloadModalFinished",
        "addDownloadedFileToBoard",
        "contentUrl",
        "QPointF",
        "pPos",
        "QSize",
        "pSize",
        "isBackground",
        "addDownloadedFileToLibrary",
        "pTitle",
        "cancelAllDownloads",
        "allDownloadsFinished",
        "onUpdateDownloadLists",
        "onDownloadProgress",
        "received",
        "onDownloadFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fileAddedToDownload'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'downloadUpdated'
        QtMocHelpers::SignalData<void(int, qint64, qint64)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::LongLong, 5 }, { QMetaType::LongLong, 6 },
        }}),
        // Signal 'downloadFinished'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'downloadFinished'
        QtMocHelpers::SignalData<void(bool, int, QUrl, QString, QByteArray)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 }, { QMetaType::Int, 4 }, { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 },
            { QMetaType::QByteArray, 12 },
        }}),
        // Signal 'downloadFinished'
        QtMocHelpers::SignalData<void(bool, sDownloadFileDesc, QByteArray)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 }, { 0x80000000 | 13, 14 }, { QMetaType::QByteArray, 12 },
        }}),
        // Signal 'downloadModalFinished'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addDownloadedFileToBoard'
        QtMocHelpers::SignalData<void(bool, QUrl, QUrl, QString, QByteArray, QPointF, QSize, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 9, 17 }, { QMetaType::QString, 11 },
            { QMetaType::QByteArray, 12 }, { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Signal 'addDownloadedFileToLibrary'
        QtMocHelpers::SignalData<void(bool, QUrl, QString, QByteArray, QString)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 }, { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 }, { QMetaType::QByteArray, 12 },
            { QMetaType::QString, 24 },
        }}),
        // Signal 'cancelAllDownloads'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allDownloadsFinished'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onUpdateDownloadLists'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDownloadProgress'
        QtMocHelpers::SlotData<void(int, qint64, qint64)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::LongLong, 29 }, { QMetaType::LongLong, 6 },
        }}),
        // Slot 'onDownloadFinished'
        QtMocHelpers::SlotData<void(int, bool, QUrl, QUrl, QString, QByteArray, QPointF, QSize, bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::Bool, 8 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 9, 17 },
            { QMetaType::QString, 11 }, { QMetaType::QByteArray, 12 }, { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 },
            { QMetaType::Bool, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBDownloadManager, qt_meta_tag_ZN17UBDownloadManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBDownloadManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UBDownloadManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UBDownloadManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17UBDownloadManagerE_t>.metaTypes,
    nullptr
} };

void UBDownloadManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBDownloadManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fileAddedToDownload(); break;
        case 1: _t->downloadUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 2: _t->downloadFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->downloadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[5]))); break;
        case 4: _t->downloadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sDownloadFileDesc>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[3]))); break;
        case 5: _t->downloadModalFinished(); break;
        case 6: _t->addDownloadedFileToBoard((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8]))); break;
        case 7: _t->addDownloadedFileToLibrary((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 8: _t->cancelAllDownloads(); break;
        case 9: _t->allDownloadsFinished(); break;
        case 10: _t->onUpdateDownloadLists(); break;
        case 11: _t->onDownloadProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 12: _t->onDownloadFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[9]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBDownloadManager::*)()>(_a, &UBDownloadManager::fileAddedToDownload, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDownloadManager::*)(int , qint64 , qint64 )>(_a, &UBDownloadManager::downloadUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDownloadManager::*)(int )>(_a, &UBDownloadManager::downloadFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDownloadManager::*)(bool , int , QUrl , QString , QByteArray )>(_a, &UBDownloadManager::downloadFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDownloadManager::*)(bool , sDownloadFileDesc , QByteArray )>(_a, &UBDownloadManager::downloadFinished, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDownloadManager::*)()>(_a, &UBDownloadManager::downloadModalFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDownloadManager::*)(bool , QUrl , QUrl , QString , QByteArray , QPointF , QSize , bool )>(_a, &UBDownloadManager::addDownloadedFileToBoard, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDownloadManager::*)(bool , QUrl , QString , QByteArray , QString )>(_a, &UBDownloadManager::addDownloadedFileToLibrary, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDownloadManager::*)()>(_a, &UBDownloadManager::cancelAllDownloads, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDownloadManager::*)()>(_a, &UBDownloadManager::allDownloadsFinished, 9))
            return;
    }
}

const QMetaObject *UBDownloadManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBDownloadManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UBDownloadManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBDownloadManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void UBDownloadManager::fileAddedToDownload()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UBDownloadManager::downloadUpdated(int _t1, qint64 _t2, qint64 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void UBDownloadManager::downloadFinished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UBDownloadManager::downloadFinished(bool _t1, int _t2, QUrl _t3, QString _t4, QByteArray _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 4
void UBDownloadManager::downloadFinished(bool _t1, sDownloadFileDesc _t2, QByteArray _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void UBDownloadManager::downloadModalFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void UBDownloadManager::addDownloadedFileToBoard(bool _t1, QUrl _t2, QUrl _t3, QString _t4, QByteArray _t5, QPointF _t6, QSize _t7, bool _t8)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8);
}

// SIGNAL 7
void UBDownloadManager::addDownloadedFileToLibrary(bool _t1, QUrl _t2, QString _t3, QByteArray _t4, QString _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 8
void UBDownloadManager::cancelAllDownloads()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void UBDownloadManager::allDownloadsFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
