/****************************************************************************
** Meta object code from reading C++ file 'UBBoardView.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/board/UBBoardView.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBBoardView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11UBBoardViewE_t {};
} // unnamed namespace

template <> constexpr inline auto UBBoardView::qt_create_metaobjectdata<qt_meta_tag_ZN11UBBoardViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBBoardView",
        "resized",
        "",
        "QResizeEvent*",
        "event",
        "shown",
        "mouseReleased",
        "painted",
        "QRectF",
        "region",
        "settingChanged",
        "QVariant",
        "newValue",
        "movingItemDestroyed",
        "item",
        "virtualKeyboardActivated",
        "b",
        "longPressEvent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'resized'
        QtMocHelpers::SignalData<void(QResizeEvent *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'shown'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mouseReleased'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'painted'
        QtMocHelpers::SignalData<void(const QRectF)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'settingChanged'
        QtMocHelpers::SlotData<void(QVariant)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'movingItemDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 14 },
        }}),
        // Slot 'movingItemDestroyed'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'virtualKeyboardActivated'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'longPressEvent'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBBoardView, qt_meta_tag_ZN11UBBoardViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBBoardView::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UBBoardViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UBBoardViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11UBBoardViewE_t>.metaTypes,
    nullptr
} };

void UBBoardView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBBoardView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resized((*reinterpret_cast<std::add_pointer_t<QResizeEvent*>>(_a[1]))); break;
        case 1: _t->shown(); break;
        case 2: _t->mouseReleased(); break;
        case 3: _t->painted((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 4: _t->settingChanged((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 5: _t->movingItemDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 6: _t->movingItemDestroyed(); break;
        case 7: _t->virtualKeyboardActivated((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->longPressEvent(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBBoardView::*)(QResizeEvent * )>(_a, &UBBoardView::resized, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardView::*)()>(_a, &UBBoardView::shown, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardView::*)()>(_a, &UBBoardView::mouseReleased, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBBoardView::*)(const QRectF )>(_a, &UBBoardView::painted, 3))
            return;
    }
}

const QMetaObject *UBBoardView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBBoardView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UBBoardViewE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int UBBoardView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void UBBoardView::resized(QResizeEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UBBoardView::shown()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UBBoardView::mouseReleased()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UBBoardView::painted(const QRectF _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
