/****************************************************************************
** Meta object code from reading C++ file 'webpage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/web/simplebrowser/webpage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'webpage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7WebPageE_t {};
} // unnamed namespace

template <> constexpr inline auto WebPage::qt_create_metaobjectdata<qt_meta_tag_ZN7WebPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebPage",
        "handleCertificateError",
        "",
        "QWebEngineCertificateError",
        "error",
        "handleAuthenticationRequired",
        "QUrl",
        "requestUrl",
        "QAuthenticator*",
        "auth",
        "handleFeaturePermissionRequested",
        "securityOrigin",
        "Feature",
        "feature",
        "handleProxyAuthenticationRequired",
        "proxyHost",
        "handleRegisterProtocolHandlerRequested",
        "QWebEngineRegisterProtocolHandlerRequest",
        "request",
        "handleSelectClientCertificate",
        "QWebEngineClientCertificateSelection",
        "clientCertSelection"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleCertificateError'
        QtMocHelpers::SlotData<void(QWebEngineCertificateError)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'handleAuthenticationRequired'
        QtMocHelpers::SlotData<void(const QUrl &, QAuthenticator *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'handleFeaturePermissionRequested'
        QtMocHelpers::SlotData<void(const QUrl &, Feature)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'handleProxyAuthenticationRequired'
        QtMocHelpers::SlotData<void(const QUrl &, QAuthenticator *, const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'handleRegisterProtocolHandlerRequested'
        QtMocHelpers::SlotData<void(QWebEngineRegisterProtocolHandlerRequest)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'handleSelectClientCertificate'
        QtMocHelpers::SlotData<void(QWebEngineClientCertificateSelection)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebPage, qt_meta_tag_ZN7WebPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWebEnginePage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7WebPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7WebPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7WebPageE_t>.metaTypes,
    nullptr
} };

void WebPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleCertificateError((*reinterpret_cast<std::add_pointer_t<QWebEngineCertificateError>>(_a[1]))); break;
        case 1: _t->handleAuthenticationRequired((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAuthenticator*>>(_a[2]))); break;
        case 2: _t->handleFeaturePermissionRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Feature>>(_a[2]))); break;
        case 3: _t->handleProxyAuthenticationRequired((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAuthenticator*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->handleRegisterProtocolHandlerRequested((*reinterpret_cast<std::add_pointer_t<QWebEngineRegisterProtocolHandlerRequest>>(_a[1]))); break;
        case 5: _t->handleSelectClientCertificate((*reinterpret_cast<std::add_pointer_t<QWebEngineClientCertificateSelection>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWebEngineCertificateError >(); break;
            }
            break;
        }
    }
}

const QMetaObject *WebPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7WebPageE_t>.strings))
        return static_cast<void*>(this);
    return QWebEnginePage::qt_metacast(_clname);
}

int WebPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWebEnginePage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
