/****************************************************************************
** Meta object code from reading C++ file 'UBFeaturesController.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/board/UBFeaturesController.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBFeaturesController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25UBFeaturesComputingThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto UBFeaturesComputingThread::qt_create_metaobjectdata<qt_meta_tag_ZN25UBFeaturesComputingThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBFeaturesComputingThread",
        "sendFeature",
        "",
        "UBFeature",
        "pFeature",
        "featureSent",
        "scanStarted",
        "scanFinished",
        "maxFilesCountEvaluated",
        "max",
        "scanCategory",
        "str",
        "scanPath"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sendFeature'
        QtMocHelpers::SignalData<void(UBFeature)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'featureSent'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scanStarted'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scanFinished'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxFilesCountEvaluated'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'scanCategory'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'scanPath'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBFeaturesComputingThread, qt_meta_tag_ZN25UBFeaturesComputingThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBFeaturesComputingThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25UBFeaturesComputingThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25UBFeaturesComputingThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25UBFeaturesComputingThreadE_t>.metaTypes,
    nullptr
} };

void UBFeaturesComputingThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBFeaturesComputingThread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sendFeature((*reinterpret_cast<std::add_pointer_t<UBFeature>>(_a[1]))); break;
        case 1: _t->featureSent(); break;
        case 2: _t->scanStarted(); break;
        case 3: _t->scanFinished(); break;
        case 4: _t->maxFilesCountEvaluated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->scanCategory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->scanPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UBFeature >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesComputingThread::*)(UBFeature )>(_a, &UBFeaturesComputingThread::sendFeature, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesComputingThread::*)()>(_a, &UBFeaturesComputingThread::featureSent, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesComputingThread::*)()>(_a, &UBFeaturesComputingThread::scanStarted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesComputingThread::*)()>(_a, &UBFeaturesComputingThread::scanFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesComputingThread::*)(int )>(_a, &UBFeaturesComputingThread::maxFilesCountEvaluated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesComputingThread::*)(const QString & )>(_a, &UBFeaturesComputingThread::scanCategory, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesComputingThread::*)(const QString & )>(_a, &UBFeaturesComputingThread::scanPath, 6))
            return;
    }
}

const QMetaObject *UBFeaturesComputingThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBFeaturesComputingThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25UBFeaturesComputingThreadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int UBFeaturesComputingThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void UBFeaturesComputingThread::sendFeature(UBFeature _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UBFeaturesComputingThread::featureSent()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UBFeaturesComputingThread::scanStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UBFeaturesComputingThread::scanFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void UBFeaturesComputingThread::maxFilesCountEvaluated(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void UBFeaturesComputingThread::scanCategory(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void UBFeaturesComputingThread::scanPath(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN20UBFeaturesControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto UBFeaturesController::qt_create_metaobjectdata<qt_meta_tag_ZN20UBFeaturesControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBFeaturesController",
        "maxFilesCountEvaluated",
        "",
        "pLimit",
        "scanStarted",
        "scanFinished",
        "featureAddedFromThread",
        "scanCategory",
        "scanPath",
        "addNewFolder",
        "name",
        "startThread",
        "createNpApiFeature",
        "str"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'maxFilesCountEvaluated'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'scanStarted'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scanFinished'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'featureAddedFromThread'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scanCategory'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'scanPath'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'addNewFolder'
        QtMocHelpers::SlotData<void(QString)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'startThread'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createNpApiFeature'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBFeaturesController, qt_meta_tag_ZN20UBFeaturesControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBFeaturesController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20UBFeaturesControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20UBFeaturesControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20UBFeaturesControllerE_t>.metaTypes,
    nullptr
} };

void UBFeaturesController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBFeaturesController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->maxFilesCountEvaluated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->scanStarted(); break;
        case 2: _t->scanFinished(); break;
        case 3: _t->featureAddedFromThread(); break;
        case 4: _t->scanCategory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->scanPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->addNewFolder((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->startThread(); break;
        case 8: _t->createNpApiFeature((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesController::*)(int )>(_a, &UBFeaturesController::maxFilesCountEvaluated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesController::*)()>(_a, &UBFeaturesController::scanStarted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesController::*)()>(_a, &UBFeaturesController::scanFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesController::*)()>(_a, &UBFeaturesController::featureAddedFromThread, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesController::*)(const QString & )>(_a, &UBFeaturesController::scanCategory, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBFeaturesController::*)(const QString & )>(_a, &UBFeaturesController::scanPath, 5))
            return;
    }
}

const QMetaObject *UBFeaturesController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBFeaturesController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20UBFeaturesControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBFeaturesController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void UBFeaturesController::maxFilesCountEvaluated(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UBFeaturesController::scanStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UBFeaturesController::scanFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UBFeaturesController::featureAddedFromThread()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void UBFeaturesController::scanCategory(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void UBFeaturesController::scanPath(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
