/****************************************************************************
** Meta object code from reading C++ file 'UBPersistenceManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/core/UBPersistenceManager.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBPersistenceManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20UBPersistenceManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto UBPersistenceManager::qt_create_metaobjectdata<qt_meta_tag_ZN20UBPersistenceManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBPersistenceManager",
        "documentCreated",
        "",
        "std::shared_ptr<UBDocumentProxy>",
        "pDocumentProxy",
        "documentMetadataChanged",
        "documentSceneDuplicated",
        "pIndex",
        "documentSceneMoved",
        "fromIndex",
        "toIndex",
        "documentSceneDeleted",
        "documentRepositoryChanged",
        "path",
        "errorString",
        "error",
        "onWorkerFinished",
        "onScenePersisted",
        "UBGraphicsScene*",
        "scene"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'documentCreated'
        QtMocHelpers::SignalData<void(std::shared_ptr<UBDocumentProxy>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentMetadataChanged'
        QtMocHelpers::SignalData<void(std::shared_ptr<UBDocumentProxy>)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentSceneDuplicated'
        QtMocHelpers::SignalData<void(std::shared_ptr<UBDocumentProxy>, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 7 },
        }}),
        // Signal 'documentSceneMoved'
        QtMocHelpers::SignalData<void(std::shared_ptr<UBDocumentProxy>, int, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'documentSceneDeleted'
        QtMocHelpers::SignalData<void(std::shared_ptr<UBDocumentProxy>, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'documentRepositoryChanged'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'errorString'
        QtMocHelpers::SlotData<void(QString)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'onWorkerFinished'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onScenePersisted'
        QtMocHelpers::SlotData<void(UBGraphicsScene *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBPersistenceManager, qt_meta_tag_ZN20UBPersistenceManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBPersistenceManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20UBPersistenceManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20UBPersistenceManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20UBPersistenceManagerE_t>.metaTypes,
    nullptr
} };

void UBPersistenceManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBPersistenceManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->documentCreated((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1]))); break;
        case 1: _t->documentMetadataChanged((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1]))); break;
        case 2: _t->documentSceneDuplicated((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->documentSceneMoved((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->documentSceneDeleted((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBDocumentProxy>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->documentRepositoryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->errorString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->onWorkerFinished(); break;
        case 8: _t->onScenePersisted((*reinterpret_cast<std::add_pointer_t<UBGraphicsScene*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UBGraphicsScene* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBPersistenceManager::*)(std::shared_ptr<UBDocumentProxy> )>(_a, &UBPersistenceManager::documentCreated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBPersistenceManager::*)(std::shared_ptr<UBDocumentProxy> )>(_a, &UBPersistenceManager::documentMetadataChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBPersistenceManager::*)(std::shared_ptr<UBDocumentProxy> , int )>(_a, &UBPersistenceManager::documentSceneDuplicated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBPersistenceManager::*)(std::shared_ptr<UBDocumentProxy> , int , int )>(_a, &UBPersistenceManager::documentSceneMoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBPersistenceManager::*)(std::shared_ptr<UBDocumentProxy> , int )>(_a, &UBPersistenceManager::documentSceneDeleted, 4))
            return;
    }
}

const QMetaObject *UBPersistenceManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBPersistenceManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20UBPersistenceManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBPersistenceManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void UBPersistenceManager::documentCreated(std::shared_ptr<UBDocumentProxy> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UBPersistenceManager::documentMetadataChanged(std::shared_ptr<UBDocumentProxy> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UBPersistenceManager::documentSceneDuplicated(std::shared_ptr<UBDocumentProxy> _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void UBPersistenceManager::documentSceneMoved(std::shared_ptr<UBDocumentProxy> _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void UBPersistenceManager::documentSceneDeleted(std::shared_ptr<UBDocumentProxy> _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
