/********************************************************************************
** Form generated from reading UI file 'youTubePublishingDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_YOUTUBEPUBLISHINGDIALOG_H
#define UI_YOUTUBEPUBLISHINGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_YouTubePublishingDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *titleLabel;
    QLineEdit *title;
    QLabel *decriptionLabel;
    QPlainTextEdit *description;
    QLabel *keywordsLabel;
    QLineEdit *keywords;
    QLabel *label;
    QComboBox *category;
    QSpacerItem *verticalSpacer;
    QLabel *label_2;
    QLineEdit *email;
    QLabel *label_3;
    QLineEdit *password;
    QLabel *label_4;
    QDialogButtonBox *dialogButtons;
    QCheckBox *youtubeCredentialsPersistence;

    void setupUi(QDialog *YouTubePublishingDialog)
    {
        if (YouTubePublishingDialog->objectName().isEmpty())
            YouTubePublishingDialog->setObjectName("YouTubePublishingDialog");
        YouTubePublishingDialog->setWindowModality(Qt::WindowModal);
        YouTubePublishingDialog->resize(540, 534);
        verticalLayout = new QVBoxLayout(YouTubePublishingDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setSpacing(6);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        titleLabel = new QLabel(YouTubePublishingDialog);
        titleLabel->setObjectName("titleLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, titleLabel);

        title = new QLineEdit(YouTubePublishingDialog);
        title->setObjectName("title");
        title->setMaxLength(60);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, title);

        decriptionLabel = new QLabel(YouTubePublishingDialog);
        decriptionLabel->setObjectName("decriptionLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, decriptionLabel);

        description = new QPlainTextEdit(YouTubePublishingDialog);
        description->setObjectName("description");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(description->sizePolicy().hasHeightForWidth());
        description->setSizePolicy(sizePolicy);
        description->setMinimumSize(QSize(0, 168));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, description);

        keywordsLabel = new QLabel(YouTubePublishingDialog);
        keywordsLabel->setObjectName("keywordsLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, keywordsLabel);

        keywords = new QLineEdit(YouTubePublishingDialog);
        keywords->setObjectName("keywords");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, keywords);

        label = new QLabel(YouTubePublishingDialog);
        label->setObjectName("label");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label);

        category = new QComboBox(YouTubePublishingDialog);
        category->setObjectName("category");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, category);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(6, QFormLayout::ItemRole::FieldRole, verticalSpacer);

        label_2 = new QLabel(YouTubePublishingDialog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_2);

        email = new QLineEdit(YouTubePublishingDialog);
        email->setObjectName("email");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, email);

        label_3 = new QLabel(YouTubePublishingDialog);
        label_3->setObjectName("label_3");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_3);

        password = new QLineEdit(YouTubePublishingDialog);
        password->setObjectName("password");
        password->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, password);

        label_4 = new QLabel(YouTubePublishingDialog);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);
        label_4->setOpenExternalLinks(true);
        label_4->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, label_4);

        dialogButtons = new QDialogButtonBox(YouTubePublishingDialog);
        dialogButtons->setObjectName("dialogButtons");
        dialogButtons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, dialogButtons);

        youtubeCredentialsPersistence = new QCheckBox(YouTubePublishingDialog);
        youtubeCredentialsPersistence->setObjectName("youtubeCredentialsPersistence");
        youtubeCredentialsPersistence->setChecked(true);

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, youtubeCredentialsPersistence);


        verticalLayout->addLayout(formLayout);


        retranslateUi(YouTubePublishingDialog);

        QMetaObject::connectSlotsByName(YouTubePublishingDialog);
    } // setupUi

    void retranslateUi(QDialog *YouTubePublishingDialog)
    {
        YouTubePublishingDialog->setWindowTitle(QCoreApplication::translate("YouTubePublishingDialog", "Publish Podcast to YouTube", nullptr));
        titleLabel->setText(QCoreApplication::translate("YouTubePublishingDialog", "Title", nullptr));
        decriptionLabel->setText(QCoreApplication::translate("YouTubePublishingDialog", "Description", nullptr));
        keywordsLabel->setText(QCoreApplication::translate("YouTubePublishingDialog", "Keywords", nullptr));
        keywords->setText(QCoreApplication::translate("YouTubePublishingDialog", "OpenBoard", nullptr));
        label->setText(QCoreApplication::translate("YouTubePublishingDialog", "Category", nullptr));
        label_2->setText(QCoreApplication::translate("YouTubePublishingDialog", "YouTube Username", nullptr));
        label_3->setText(QCoreApplication::translate("YouTubePublishingDialog", "YouTube Password", nullptr));
        label_4->setText(QCoreApplication::translate("YouTubePublishingDialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Lucida Grande'; font-size:10pt;\">By clicking 'Upload,' you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at </span><a href=\"http://www.youtube.com/t/terms\"><span style=\" font-family:'Lucida Grande'; font-size:10pt; text-decoration: underline; color:#0000ff;\">http://www.youtube.com/t/terms</span></a></p></body></html>", nullptr));
        youtubeCredentialsPersistence->setText(QCoreApplication::translate("YouTubePublishingDialog", "Restore credentials on reboot", nullptr));
    } // retranslateUi

};

namespace Ui {
    class YouTubePublishingDialog: public Ui_YouTubePublishingDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_YOUTUBEPUBLISHINGDIALOG_H
