/****************************************************************************
** Meta object code from reading C++ file 'UBKeyboardPalette.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/gui/UBKeyboardPalette.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBKeyboardPalette.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17UBKeyboardPaletteE_t {};
} // unnamed namespace

template <> constexpr inline auto UBKeyboardPalette::qt_create_metaobjectdata<qt_meta_tag_ZN17UBKeyboardPaletteE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBKeyboardPalette",
        "moved",
        "",
        "QPoint",
        "localeChanged",
        "keyboardActivated",
        "syncPosition",
        "pos",
        "syncLocale",
        "nLocale",
        "keyboardPaletteButtonSizeChanged",
        "QVariant",
        "size",
        "onActivated",
        "b",
        "onDeactivated",
        "showKeyboard",
        "show",
        "hideKeyboard"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'moved'
        QtMocHelpers::SignalData<void(const QPoint &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'localeChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'keyboardActivated'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'syncPosition'
        QtMocHelpers::SlotData<void(const QPoint &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Slot 'syncLocale'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'keyboardPaletteButtonSizeChanged'
        QtMocHelpers::SlotData<void(QVariant)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'onActivated'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'onDeactivated'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showKeyboard'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'hideKeyboard'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBKeyboardPalette, qt_meta_tag_ZN17UBKeyboardPaletteE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBKeyboardPalette::staticMetaObject = { {
    QMetaObject::SuperData::link<UBActionPalette::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UBKeyboardPaletteE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UBKeyboardPaletteE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17UBKeyboardPaletteE_t>.metaTypes,
    nullptr
} };

void UBKeyboardPalette::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBKeyboardPalette *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->moved((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 1: _t->localeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->keyboardActivated((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->syncPosition((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 4: _t->syncLocale((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->keyboardPaletteButtonSizeChanged((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 6: _t->onActivated((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->onDeactivated(); break;
        case 8: _t->showKeyboard((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->hideKeyboard(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBKeyboardPalette::*)(const QPoint & )>(_a, &UBKeyboardPalette::moved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBKeyboardPalette::*)(int )>(_a, &UBKeyboardPalette::localeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBKeyboardPalette::*)(bool )>(_a, &UBKeyboardPalette::keyboardActivated, 2))
            return;
    }
}

const QMetaObject *UBKeyboardPalette::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBKeyboardPalette::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UBKeyboardPaletteE_t>.strings))
        return static_cast<void*>(this);
    return UBActionPalette::qt_metacast(_clname);
}

int UBKeyboardPalette::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBActionPalette::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void UBKeyboardPalette::moved(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UBKeyboardPalette::localeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UBKeyboardPalette::keyboardActivated(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN16UBKeyboardButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto UBKeyboardButton::qt_create_metaobjectdata<qt_meta_tag_ZN16UBKeyboardButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBKeyboardButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBKeyboardButton, qt_meta_tag_ZN16UBKeyboardButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBKeyboardButton::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16UBKeyboardButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16UBKeyboardButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16UBKeyboardButtonE_t>.metaTypes,
    nullptr
} };

void UBKeyboardButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBKeyboardButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UBKeyboardButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBKeyboardButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16UBKeyboardButtonE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int UBKeyboardButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN11UBKeyButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto UBKeyButton::qt_create_metaobjectdata<qt_meta_tag_ZN11UBKeyButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBKeyButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBKeyButton, qt_meta_tag_ZN11UBKeyButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBKeyButton::staticMetaObject = { {
    QMetaObject::SuperData::link<UBKeyboardButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UBKeyButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UBKeyButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11UBKeyButtonE_t>.metaTypes,
    nullptr
} };

void UBKeyButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBKeyButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UBKeyButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBKeyButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UBKeyButtonE_t>.strings))
        return static_cast<void*>(this);
    return UBKeyboardButton::qt_metacast(_clname);
}

int UBKeyButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBKeyboardButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13UBCntrlButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto UBCntrlButton::qt_create_metaobjectdata<qt_meta_tag_ZN13UBCntrlButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBCntrlButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBCntrlButton, qt_meta_tag_ZN13UBCntrlButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBCntrlButton::staticMetaObject = { {
    QMetaObject::SuperData::link<UBKeyboardButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UBCntrlButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UBCntrlButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13UBCntrlButtonE_t>.metaTypes,
    nullptr
} };

void UBCntrlButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBCntrlButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UBCntrlButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBCntrlButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UBCntrlButtonE_t>.strings))
        return static_cast<void*>(this);
    return UBKeyboardButton::qt_metacast(_clname);
}

int UBCntrlButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBKeyboardButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN16UBCapsLockButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto UBCapsLockButton::qt_create_metaobjectdata<qt_meta_tag_ZN16UBCapsLockButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBCapsLockButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBCapsLockButton, qt_meta_tag_ZN16UBCapsLockButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBCapsLockButton::staticMetaObject = { {
    QMetaObject::SuperData::link<UBKeyboardButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16UBCapsLockButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16UBCapsLockButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16UBCapsLockButtonE_t>.metaTypes,
    nullptr
} };

void UBCapsLockButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBCapsLockButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UBCapsLockButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBCapsLockButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16UBCapsLockButtonE_t>.strings))
        return static_cast<void*>(this);
    return UBKeyboardButton::qt_metacast(_clname);
}

int UBCapsLockButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBKeyboardButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13UBShiftButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto UBShiftButton::qt_create_metaobjectdata<qt_meta_tag_ZN13UBShiftButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBShiftButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBShiftButton, qt_meta_tag_ZN13UBShiftButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBShiftButton::staticMetaObject = { {
    QMetaObject::SuperData::link<UBKeyboardButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UBShiftButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UBShiftButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13UBShiftButtonE_t>.metaTypes,
    nullptr
} };

void UBShiftButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBShiftButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UBShiftButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBShiftButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UBShiftButtonE_t>.strings))
        return static_cast<void*>(this);
    return UBKeyboardButton::qt_metacast(_clname);
}

int UBShiftButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBKeyboardButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14UBLocaleButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto UBLocaleButton::qt_create_metaobjectdata<qt_meta_tag_ZN14UBLocaleButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBLocaleButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBLocaleButton, qt_meta_tag_ZN14UBLocaleButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBLocaleButton::staticMetaObject = { {
    QMetaObject::SuperData::link<UBKeyboardButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14UBLocaleButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14UBLocaleButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14UBLocaleButtonE_t>.metaTypes,
    nullptr
} };

void UBLocaleButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBLocaleButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UBLocaleButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBLocaleButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14UBLocaleButtonE_t>.strings))
        return static_cast<void*>(this);
    return UBKeyboardButton::qt_metacast(_clname);
}

int UBLocaleButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBKeyboardButton::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
