/****************************************************************************
** Meta object code from reading C++ file 'UBWidgetUniboardAPI.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/api/UBWidgetUniboardAPI.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBWidgetUniboardAPI.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19UBWidgetUniboardAPIE_t {};
} // unnamed namespace

template <> constexpr inline auto UBWidgetUniboardAPI::qt_create_metaobjectdata<qt_meta_tag_ZN19UBWidgetUniboardAPIE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBWidgetUniboardAPI",
        "dropDataChanged",
        "",
        "data",
        "setScene",
        "std::shared_ptr<UBGraphicsScene>",
        "pScene",
        "setTool",
        "toolString",
        "setPenColor",
        "penColor",
        "setMarkerColor",
        "pageThumbnail",
        "pageNumber",
        "zoom",
        "factor",
        "x",
        "y",
        "move",
        "moveTo",
        "drawLineTo",
        "pWidth",
        "eraseLineTo",
        "clear",
        "setBackground",
        "pIsDark",
        "pIsCrossed",
        "addObject",
        "pUrl",
        "width",
        "height",
        "background",
        "resize",
        "locale",
        "setPreference",
        "key",
        "value",
        "preference",
        "pDefault",
        "preferenceKeys",
        "showMessage",
        "message",
        "centerOn",
        "addText",
        "text",
        "font",
        "bold",
        "italic",
        "sendFileMetadata",
        "metaData",
        "enableDropOnWidget",
        "enable",
        "processFileDrop",
        "ProcessDropEvent",
        "QGraphicsSceneDragDropEvent*",
        "isDropableData",
        "const QMimeData*",
        "pMimeData",
        "onDownloadFinished",
        "pSuccess",
        "sDownloadFileDesc",
        "desc",
        "pData",
        "uuid",
        "lang",
        "messages",
        "datastore",
        "dropData"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dropDataChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setScene'
        QtMocHelpers::SlotData<void(std::shared_ptr<UBGraphicsScene>)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setTool'
        QtMocHelpers::SlotData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'setPenColor'
        QtMocHelpers::SlotData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'setMarkerColor'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'pageThumbnail'
        QtMocHelpers::SlotData<QString(const int)>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'zoom'
        QtMocHelpers::SlotData<void(const qreal, const qreal, const qreal)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 15 }, { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 },
        }}),
        // Slot 'move'
        QtMocHelpers::SlotData<void(const qreal, const qreal)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 },
        }}),
        // Slot 'moveTo'
        QtMocHelpers::SlotData<void(const qreal, const qreal)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 },
        }}),
        // Slot 'drawLineTo'
        QtMocHelpers::SlotData<void(const qreal, const qreal, const qreal)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 }, { QMetaType::QReal, 21 },
        }}),
        // Slot 'eraseLineTo'
        QtMocHelpers::SlotData<void(const qreal, const qreal, const qreal)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 }, { QMetaType::QReal, 21 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBackground'
        QtMocHelpers::SlotData<void(bool, bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'addObject'
        QtMocHelpers::SlotData<void(QString, int, int, int, int, bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::Int, 29 }, { QMetaType::Int, 30 }, { QMetaType::Int, 16 },
            { QMetaType::Int, 17 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'addObject'
        QtMocHelpers::SlotData<void(QString, int, int, int, int)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::Int, 29 }, { QMetaType::Int, 30 }, { QMetaType::Int, 16 },
            { QMetaType::Int, 17 },
        }}),
        // Slot 'addObject'
        QtMocHelpers::SlotData<void(QString, int, int, int)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::Int, 29 }, { QMetaType::Int, 30 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'addObject'
        QtMocHelpers::SlotData<void(QString, int, int)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::Int, 29 }, { QMetaType::Int, 30 },
        }}),
        // Slot 'addObject'
        QtMocHelpers::SlotData<void(QString, int)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'addObject'
        QtMocHelpers::SlotData<void(QString)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'resize'
        QtMocHelpers::SlotData<void(qreal, qreal)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 29 }, { QMetaType::QReal, 30 },
        }}),
        // Slot 'locale'
        QtMocHelpers::SlotData<QString()>(33, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setPreference'
        QtMocHelpers::SlotData<void(const QString &, QString)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 }, { QMetaType::QString, 36 },
        }}),
        // Slot 'preference'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(37, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 35 }, { QMetaType::QString, 38 },
        }}),
        // Slot 'preference'
        QtMocHelpers::SlotData<QString(const QString &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'preferenceKeys'
        QtMocHelpers::SlotData<QStringList()>(39, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'showMessage'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const qreal, const qreal)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 },
        }}),
        // Slot 'addText'
        QtMocHelpers::SlotData<void(const QString &, const qreal, const qreal, const int, const QString &, bool, bool)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 }, { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 }, { QMetaType::Int, 30 },
            { QMetaType::QString, 45 }, { QMetaType::Bool, 46 }, { QMetaType::Bool, 47 },
        }}),
        // Slot 'addText'
        QtMocHelpers::SlotData<void(const QString &, const qreal, const qreal, const int, const QString &, bool)>(43, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 44 }, { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 }, { QMetaType::Int, 30 },
            { QMetaType::QString, 45 }, { QMetaType::Bool, 46 },
        }}),
        // Slot 'addText'
        QtMocHelpers::SlotData<void(const QString &, const qreal, const qreal, const int, const QString &)>(43, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 44 }, { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 }, { QMetaType::Int, 30 },
            { QMetaType::QString, 45 },
        }}),
        // Slot 'addText'
        QtMocHelpers::SlotData<void(const QString &, const qreal, const qreal, const int)>(43, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 44 }, { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 }, { QMetaType::Int, 30 },
        }}),
        // Slot 'addText'
        QtMocHelpers::SlotData<void(const QString &, const qreal, const qreal)>(43, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 44 }, { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 },
        }}),
        // Slot 'sendFileMetadata'
        QtMocHelpers::SlotData<void(QString)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Slot 'enableDropOnWidget'
        QtMocHelpers::SlotData<void(bool, bool)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 }, { QMetaType::Bool, 52 },
        }}),
        // Slot 'enableDropOnWidget'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'enableDropOnWidget'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'ProcessDropEvent'
        QtMocHelpers::SlotData<bool(QGraphicsSceneDragDropEvent *)>(53, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 54, 2 },
        }}),
        // Slot 'isDropableData'
        QtMocHelpers::SlotData<bool(const QMimeData *) const>(55, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'onDownloadFinished'
        QtMocHelpers::SlotData<void(bool, sDownloadFileDesc, QByteArray)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 59 }, { 0x80000000 | 60, 61 }, { QMetaType::QByteArray, 62 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'uuid'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lang'
        QtMocHelpers::PropertyData<QString>(64, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'messages'
        QtMocHelpers::PropertyData<QObject*>(65, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'datastore'
        QtMocHelpers::PropertyData<QObject*>(66, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dropData'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBWidgetUniboardAPI, qt_meta_tag_ZN19UBWidgetUniboardAPIE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBWidgetUniboardAPI::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBWidgetUniboardAPIE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBWidgetUniboardAPIE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19UBWidgetUniboardAPIE_t>.metaTypes,
    nullptr
} };

void UBWidgetUniboardAPI::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBWidgetUniboardAPI *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dropDataChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->setScene((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<UBGraphicsScene>>>(_a[1]))); break;
        case 2: _t->setTool((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->setPenColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->setMarkerColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { QString _r = _t->pageThumbnail((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->zoom((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3]))); break;
        case 7: _t->move((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 8: _t->moveTo((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 9: _t->drawLineTo((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3]))); break;
        case 10: _t->eraseLineTo((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3]))); break;
        case 11: _t->clear(); break;
        case 12: _t->setBackground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->addObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 14: _t->addObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 15: _t->addObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 16: _t->addObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 17: _t->addObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 18: _t->addObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->resize((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 20: { QString _r = _t->locale();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->setPreference((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: { QString _r = _t->preference((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: { QString _r = _t->preference((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: { QStringList _r = _t->preferenceKeys();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->showMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->centerOn((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 27: _t->addText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7]))); break;
        case 28: _t->addText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 29: _t->addText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 30: _t->addText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 31: _t->addText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3]))); break;
        case 32: _t->sendFileMetadata((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->enableDropOnWidget((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 34: _t->enableDropOnWidget((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->enableDropOnWidget(); break;
        case 36: { bool _r = _t->ProcessDropEvent((*reinterpret_cast<std::add_pointer_t<QGraphicsSceneDragDropEvent*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->isDropableData((*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->onDownloadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sDownloadFileDesc>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBWidgetUniboardAPI::*)(const QString & )>(_a, &UBWidgetUniboardAPI::dropDataChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->uuid(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->lang(); break;
        case 2: *reinterpret_cast<QObject**>(_v) = _t->messages(); break;
        case 3: *reinterpret_cast<QObject**>(_v) = _t->datastore(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->mDropData; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setDropData(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *UBWidgetUniboardAPI::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBWidgetUniboardAPI::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBWidgetUniboardAPIE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBWidgetUniboardAPI::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 39;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void UBWidgetUniboardAPI::dropDataChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN14UBDatastoreAPIE_t {};
} // unnamed namespace

template <> constexpr inline auto UBDatastoreAPI::qt_create_metaobjectdata<qt_meta_tag_ZN14UBDatastoreAPIE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBDatastoreAPI",
        "document"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'document'
        QtMocHelpers::PropertyData<QObject*>(1, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBDatastoreAPI, qt_meta_tag_ZN14UBDatastoreAPIE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBDatastoreAPI::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14UBDatastoreAPIE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14UBDatastoreAPIE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14UBDatastoreAPIE_t>.metaTypes,
    nullptr
} };

void UBDatastoreAPI::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBDatastoreAPI *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->document(); break;
        default: break;
        }
    }
}

const QMetaObject *UBDatastoreAPI::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBDatastoreAPI::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14UBDatastoreAPIE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBDatastoreAPI::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN22UBDocumentDatastoreAPIE_t {};
} // unnamed namespace

template <> constexpr inline auto UBDocumentDatastoreAPI::qt_create_metaobjectdata<qt_meta_tag_ZN22UBDocumentDatastoreAPIE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBDocumentDatastoreAPI",
        "key",
        "",
        "index",
        "getItem",
        "setItem",
        "value",
        "removeItem",
        "clear"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'key'
        QtMocHelpers::SlotData<QString(int)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'getItem'
        QtMocHelpers::SlotData<QString(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 1 },
        }}),
        // Slot 'setItem'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 1 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'removeItem'
        QtMocHelpers::SlotData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 1 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBDocumentDatastoreAPI, qt_meta_tag_ZN22UBDocumentDatastoreAPIE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBDocumentDatastoreAPI::staticMetaObject = { {
    QMetaObject::SuperData::link<UBW3CWebStorage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22UBDocumentDatastoreAPIE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22UBDocumentDatastoreAPIE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22UBDocumentDatastoreAPIE_t>.metaTypes,
    nullptr
} };

void UBDocumentDatastoreAPI::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBDocumentDatastoreAPI *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->key((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->getItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->setItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->removeItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->clear(); break;
        default: ;
        }
    }
}

const QMetaObject *UBDocumentDatastoreAPI::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBDocumentDatastoreAPI::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22UBDocumentDatastoreAPIE_t>.strings))
        return static_cast<void*>(this);
    return UBW3CWebStorage::qt_metacast(_clname);
}

int UBDocumentDatastoreAPI::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBW3CWebStorage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
