/****************************************************************************
** Meta object code from reading C++ file 'UBMagnifer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/gui/UBMagnifer.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBMagnifer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11UBMagnifierE_t {};
} // unnamed namespace

template <> constexpr inline auto UBMagnifier::qt_create_metaobjectdata<qt_meta_tag_ZN11UBMagnifierE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBMagnifier",
        "magnifierMoved_Signal",
        "",
        "QPoint",
        "newPos",
        "magnifierClose_Signal",
        "magnifierZoomIn_Signal",
        "magnifierZoomOut_Signal",
        "magnifierResized_Signal",
        "newPercentSize",
        "magnifierDrawingModeChange_Signal",
        "mode",
        "slot_refresh"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'magnifierMoved_Signal'
        QtMocHelpers::SignalData<void(QPoint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'magnifierClose_Signal'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'magnifierZoomIn_Signal'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'magnifierZoomOut_Signal'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'magnifierResized_Signal'
        QtMocHelpers::SignalData<void(qreal)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 9 },
        }}),
        // Signal 'magnifierDrawingModeChange_Signal'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'slot_refresh'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBMagnifier, qt_meta_tag_ZN11UBMagnifierE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBMagnifier::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UBMagnifierE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UBMagnifierE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11UBMagnifierE_t>.metaTypes,
    nullptr
} };

void UBMagnifier::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBMagnifier *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->magnifierMoved_Signal((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 1: _t->magnifierClose_Signal(); break;
        case 2: _t->magnifierZoomIn_Signal(); break;
        case 3: _t->magnifierZoomOut_Signal(); break;
        case 4: _t->magnifierResized_Signal((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 5: _t->magnifierDrawingModeChange_Signal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->slot_refresh(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBMagnifier::*)(QPoint )>(_a, &UBMagnifier::magnifierMoved_Signal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBMagnifier::*)()>(_a, &UBMagnifier::magnifierClose_Signal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBMagnifier::*)()>(_a, &UBMagnifier::magnifierZoomIn_Signal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBMagnifier::*)()>(_a, &UBMagnifier::magnifierZoomOut_Signal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBMagnifier::*)(qreal )>(_a, &UBMagnifier::magnifierResized_Signal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBMagnifier::*)(int )>(_a, &UBMagnifier::magnifierDrawingModeChange_Signal, 5))
            return;
    }
}

const QMetaObject *UBMagnifier::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBMagnifier::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UBMagnifierE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int UBMagnifier::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void UBMagnifier::magnifierMoved_Signal(QPoint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UBMagnifier::magnifierClose_Signal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UBMagnifier::magnifierZoomIn_Signal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UBMagnifier::magnifierZoomOut_Signal()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void UBMagnifier::magnifierResized_Signal(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void UBMagnifier::magnifierDrawingModeChange_Signal(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
