/********************************************************************************
** Form generated from reading UI file 'intranetPodcastPublishingDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INTRANETPODCASTPUBLISHINGDIALOG_H
#define UI_INTRANETPODCASTPUBLISHINGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_IntranetPodcastPublishingDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *titleLabel;
    QLineEdit *title;
    QLabel *decriptionLabel;
    QPlainTextEdit *description;
    QLabel *keywordsLabel;
    QLineEdit *author;
    QDialogButtonBox *dialogButtons;

    void setupUi(QDialog *IntranetPodcastPublishingDialog)
    {
        if (IntranetPodcastPublishingDialog->objectName().isEmpty())
            IntranetPodcastPublishingDialog->setObjectName("IntranetPodcastPublishingDialog");
        IntranetPodcastPublishingDialog->setWindowModality(Qt::WindowModal);
        IntranetPodcastPublishingDialog->resize(540, 303);
        verticalLayout = new QVBoxLayout(IntranetPodcastPublishingDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setSpacing(6);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        titleLabel = new QLabel(IntranetPodcastPublishingDialog);
        titleLabel->setObjectName("titleLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, titleLabel);

        title = new QLineEdit(IntranetPodcastPublishingDialog);
        title->setObjectName("title");
        title->setMaxLength(60);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, title);

        decriptionLabel = new QLabel(IntranetPodcastPublishingDialog);
        decriptionLabel->setObjectName("decriptionLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, decriptionLabel);

        description = new QPlainTextEdit(IntranetPodcastPublishingDialog);
        description->setObjectName("description");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(description->sizePolicy().hasHeightForWidth());
        description->setSizePolicy(sizePolicy);
        description->setMinimumSize(QSize(0, 168));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, description);

        keywordsLabel = new QLabel(IntranetPodcastPublishingDialog);
        keywordsLabel->setObjectName("keywordsLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, keywordsLabel);

        author = new QLineEdit(IntranetPodcastPublishingDialog);
        author->setObjectName("author");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, author);

        dialogButtons = new QDialogButtonBox(IntranetPodcastPublishingDialog);
        dialogButtons->setObjectName("dialogButtons");
        dialogButtons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, dialogButtons);


        verticalLayout->addLayout(formLayout);


        retranslateUi(IntranetPodcastPublishingDialog);

        QMetaObject::connectSlotsByName(IntranetPodcastPublishingDialog);
    } // setupUi

    void retranslateUi(QDialog *IntranetPodcastPublishingDialog)
    {
        IntranetPodcastPublishingDialog->setWindowTitle(QCoreApplication::translate("IntranetPodcastPublishingDialog", "Publish to Intranet", nullptr));
        titleLabel->setText(QCoreApplication::translate("IntranetPodcastPublishingDialog", "Title", nullptr));
        decriptionLabel->setText(QCoreApplication::translate("IntranetPodcastPublishingDialog", "Description", nullptr));
        keywordsLabel->setText(QCoreApplication::translate("IntranetPodcastPublishingDialog", "Author", nullptr));
        author->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class IntranetPodcastPublishingDialog: public Ui_IntranetPodcastPublishingDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INTRANETPODCASTPUBLISHINGDIALOG_H
