/****************************************************************************
** Meta object code from reading C++ file 'UBDesktopAnnotationController.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/desktop/UBDesktopAnnotationController.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBDesktopAnnotationController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29UBDesktopAnnotationControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto UBDesktopAnnotationController::qt_create_metaobjectdata<qt_meta_tag_ZN29UBDesktopAnnotationControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBDesktopAnnotationController",
        "imageCaptured",
        "",
        "QPixmap",
        "pCapturedPixmap",
        "pageMode",
        "restoreUniboard",
        "screenLayoutChanged",
        "goToUniboard",
        "customCapture",
        "screenCapture",
        "updateShowHideState",
        "pEnabled",
        "close",
        "stylusToolChanged",
        "tool",
        "updateBackground",
        "updateColors",
        "desktopPenActionToggled",
        "checked",
        "desktopMarkerActionToggled",
        "desktopEraserActionToggled",
        "eraseDesktopAnnotations",
        "penActionPressed",
        "markerActionPressed",
        "eraserActionPressed",
        "penActionReleased",
        "markerActionReleased",
        "eraserActionReleased",
        "selectorActionPressed",
        "selectorActionReleased",
        "pointerActionPressed",
        "pointerActionReleased",
        "switchCursor",
        "onDesktopPaletteMaximized",
        "onDesktopPaletteMinimize",
        "onTransparentWidgetResized",
        "refreshMask",
        "onToolClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'imageCaptured'
        QtMocHelpers::SignalData<void(const QPixmap &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'restoreUniboard'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'screenLayoutChanged'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goToUniboard'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'customCapture'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'screenCapture'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateShowHideState'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stylusToolChanged'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'updateBackground'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateColors'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'desktopPenActionToggled'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'desktopMarkerActionToggled'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'desktopEraserActionToggled'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'eraseDesktopAnnotations'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'penActionPressed'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'markerActionPressed'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'eraserActionPressed'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'penActionReleased'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'markerActionReleased'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'eraserActionReleased'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectorActionPressed'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectorActionReleased'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pointerActionPressed'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pointerActionReleased'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'switchCursor'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'onDesktopPaletteMaximized'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDesktopPaletteMinimize'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTransparentWidgetResized'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshMask'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onToolClicked'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBDesktopAnnotationController, qt_meta_tag_ZN29UBDesktopAnnotationControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBDesktopAnnotationController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29UBDesktopAnnotationControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29UBDesktopAnnotationControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29UBDesktopAnnotationControllerE_t>.metaTypes,
    nullptr
} };

void UBDesktopAnnotationController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBDesktopAnnotationController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->imageCaptured((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->restoreUniboard(); break;
        case 2: _t->screenLayoutChanged(); break;
        case 3: _t->goToUniboard(); break;
        case 4: _t->customCapture(); break;
        case 5: _t->screenCapture(); break;
        case 6: _t->updateShowHideState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->close(); break;
        case 8: _t->stylusToolChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->updateBackground(); break;
        case 10: _t->updateColors(); break;
        case 11: _t->desktopPenActionToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->desktopMarkerActionToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->desktopEraserActionToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->eraseDesktopAnnotations(); break;
        case 15: _t->penActionPressed(); break;
        case 16: _t->markerActionPressed(); break;
        case 17: _t->eraserActionPressed(); break;
        case 18: _t->penActionReleased(); break;
        case 19: _t->markerActionReleased(); break;
        case 20: _t->eraserActionReleased(); break;
        case 21: _t->selectorActionPressed(); break;
        case 22: _t->selectorActionReleased(); break;
        case 23: _t->pointerActionPressed(); break;
        case 24: _t->pointerActionReleased(); break;
        case 25: _t->switchCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->onDesktopPaletteMaximized(); break;
        case 27: _t->onDesktopPaletteMinimize(); break;
        case 28: _t->onTransparentWidgetResized(); break;
        case 29: _t->refreshMask(); break;
        case 30: _t->onToolClicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBDesktopAnnotationController::*)(const QPixmap & , bool )>(_a, &UBDesktopAnnotationController::imageCaptured, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDesktopAnnotationController::*)()>(_a, &UBDesktopAnnotationController::restoreUniboard, 1))
            return;
    }
}

const QMetaObject *UBDesktopAnnotationController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBDesktopAnnotationController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29UBDesktopAnnotationControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBDesktopAnnotationController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void UBDesktopAnnotationController::imageCaptured(const QPixmap & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void UBDesktopAnnotationController::restoreUniboard()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
