/****************************************************************************
** Meta object code from reading C++ file 'UBDrawingController.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/board/UBDrawingController.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBDrawingController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19UBDrawingControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto UBDrawingController::qt_create_metaobjectdata<qt_meta_tag_ZN19UBDrawingControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBDrawingController",
        "stylusToolChanged",
        "",
        "tool",
        "previousTool",
        "colorPaletteChanged",
        "lineWidthIndexChanged",
        "index",
        "colorIndexChanged",
        "setStylusTool",
        "setLineWidthIndex",
        "setColorIndex",
        "setEraserWidthIndex",
        "penToolSelected",
        "checked",
        "eraserToolSelected",
        "markerToolSelected",
        "selectorToolSelected",
        "playToolSelected",
        "handToolSelected",
        "zoomInToolSelected",
        "zoomOutToolSelected",
        "pointerToolSelected",
        "lineToolSelected",
        "textToolSelected",
        "captureToolSelected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stylusToolChanged'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'stylusToolChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'colorPaletteChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineWidthIndexChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'colorIndexChanged'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setStylusTool'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setLineWidthIndex'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setColorIndex'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setEraserWidthIndex'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'penToolSelected'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'eraserToolSelected'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'markerToolSelected'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'selectorToolSelected'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'playToolSelected'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'handToolSelected'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'zoomInToolSelected'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'zoomOutToolSelected'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'pointerToolSelected'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'lineToolSelected'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'textToolSelected'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'captureToolSelected'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBDrawingController, qt_meta_tag_ZN19UBDrawingControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBDrawingController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBDrawingControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBDrawingControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19UBDrawingControllerE_t>.metaTypes,
    nullptr
} };

void UBDrawingController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBDrawingController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stylusToolChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->stylusToolChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->colorPaletteChanged(); break;
        case 3: _t->lineWidthIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->colorIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->setStylusTool((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->setLineWidthIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->setColorIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setEraserWidthIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->penToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->eraserToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->markerToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->selectorToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->playToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->handToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->zoomInToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->zoomOutToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->pointerToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->lineToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->textToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->captureToolSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBDrawingController::*)(int , int )>(_a, &UBDrawingController::stylusToolChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDrawingController::*)()>(_a, &UBDrawingController::colorPaletteChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDrawingController::*)(int )>(_a, &UBDrawingController::lineWidthIndexChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDrawingController::*)(int )>(_a, &UBDrawingController::colorIndexChanged, 4))
            return;
    }
}

const QMetaObject *UBDrawingController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBDrawingController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UBDrawingControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBDrawingController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void UBDrawingController::stylusToolChanged(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 2
void UBDrawingController::colorPaletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UBDrawingController::lineWidthIndexChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UBDrawingController::colorIndexChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
