/****************************************************************************
** Meta object code from reading C++ file 'UBWebController.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/web/UBWebController.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBWebController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15UBWebControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto UBWebController::qt_create_metaobjectdata<qt_meta_tag_ZN15UBWebControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBWebController",
        "imageCaptured",
        "",
        "QPixmap",
        "pCapturedPixmap",
        "pageMode",
        "QUrl",
        "source",
        "activeWebPageChanged",
        "WebView*",
        "pWebView",
        "screenLayoutChanged",
        "setSourceWidget",
        "QWidget*",
        "pWidget",
        "captureWindow",
        "customCapture",
        "toogleMirroring",
        "checked",
        "copy",
        "paste",
        "cut",
        "aboutToShowBackMenu",
        "aboutToShowForwardMenu",
        "openActionUrl",
        "QAction*",
        "action",
        "tabCreated",
        "webView",
        "activePageChanged",
        "trap",
        "onEmbedParsed",
        "QWebEngineView*",
        "view",
        "hasEmbeddedContent",
        "onOpenTutorial",
        "onHintsAndTips",
        "captureStripe",
        "QPointF",
        "pos",
        "QSize",
        "size",
        "QPixmap*",
        "pix",
        "scrollPosition",
        "CookiePolicy",
        "DenyAll",
        "DenyThirdParty",
        "AcceptAll"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'imageCaptured'
        QtMocHelpers::SignalData<void(const QPixmap &, bool, const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'activeWebPageChanged'
        QtMocHelpers::SignalData<void(WebView *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'screenLayoutChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSourceWidget'
        QtMocHelpers::SlotData<void(QWidget *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'captureWindow'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'customCapture'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toogleMirroring'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cut'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'aboutToShowBackMenu'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'aboutToShowForwardMenu'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openActionUrl'
        QtMocHelpers::SlotData<void(QAction *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'tabCreated'
        QtMocHelpers::SlotData<void(WebView *)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 28 },
        }}),
        // Slot 'activePageChanged'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'trap'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onEmbedParsed'
        QtMocHelpers::SlotData<void(QWebEngineView *, bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'onOpenTutorial'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onHintsAndTips'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'captureStripe'
        QtMocHelpers::SlotData<void(QPointF, QSize, QPixmap *, QPointF)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { 0x80000000 | 40, 41 }, { 0x80000000 | 42, 43 }, { 0x80000000 | 38, 44 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CookiePolicy'
        QtMocHelpers::EnumData<enum CookiePolicy>(45, 45, QMC::EnumFlags{}).add({
            {   46, CookiePolicy::DenyAll },
            {   47, CookiePolicy::DenyThirdParty },
            {   48, CookiePolicy::AcceptAll },
        }),
    };
    return QtMocHelpers::metaObjectData<UBWebController, qt_meta_tag_ZN15UBWebControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBWebController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15UBWebControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15UBWebControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15UBWebControllerE_t>.metaTypes,
    nullptr
} };

void UBWebController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBWebController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->imageCaptured((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3]))); break;
        case 1: _t->activeWebPageChanged((*reinterpret_cast<std::add_pointer_t<WebView*>>(_a[1]))); break;
        case 2: _t->screenLayoutChanged(); break;
        case 3: _t->setSourceWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 4: _t->captureWindow(); break;
        case 5: _t->customCapture(); break;
        case 6: _t->toogleMirroring((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->copy(); break;
        case 8: _t->paste(); break;
        case 9: _t->cut(); break;
        case 10: _t->aboutToShowBackMenu(); break;
        case 11: _t->aboutToShowForwardMenu(); break;
        case 12: _t->openActionUrl((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 13: _t->tabCreated((*reinterpret_cast<std::add_pointer_t<WebView*>>(_a[1]))); break;
        case 14: _t->activePageChanged(); break;
        case 15: _t->trap(); break;
        case 16: _t->onEmbedParsed((*reinterpret_cast<std::add_pointer_t<QWebEngineView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 17: _t->onOpenTutorial(); break;
        case 18: _t->onHintsAndTips(); break;
        case 19: _t->captureStripe((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPixmap*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBWebController::*)(const QPixmap & , bool , const QUrl & )>(_a, &UBWebController::imageCaptured, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBWebController::*)(WebView * )>(_a, &UBWebController::activeWebPageChanged, 1))
            return;
    }
}

const QMetaObject *UBWebController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBWebController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15UBWebControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UBWebController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void UBWebController::imageCaptured(const QPixmap & _t1, bool _t2, const QUrl & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void UBWebController::activeWebPageChanged(WebView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
