/****************************************************************************
** Meta object code from reading C++ file 'UBDesktopPalette.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../OpenBoard/src/desktop/UBDesktopPalette.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UBDesktopPalette.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16UBDesktopPaletteE_t {};
} // unnamed namespace

template <> constexpr inline auto UBDesktopPalette::qt_create_metaobjectdata<qt_meta_tag_ZN16UBDesktopPaletteE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UBDesktopPalette",
        "uniboardClick",
        "",
        "customClick",
        "screenClick",
        "refreshMask",
        "stylusToolChanged",
        "tool",
        "showHideClick",
        "checked",
        "updateShowHideState",
        "pShowEnabled",
        "setShowHideButtonVisible",
        "visible",
        "setDisplaySelectButtonVisible",
        "show",
        "minimizeMe",
        "eMinimizedLocation",
        "location",
        "maximizeMe",
        "parentResized"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'uniboardClick'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'customClick'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenClick'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshMask'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stylusToolChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'showHideClick'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'updateShowHideState'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setShowHideButtonVisible'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'setDisplaySelectButtonVisible'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'minimizeMe'
        QtMocHelpers::SlotData<void(eMinimizedLocation)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'maximizeMe'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'parentResized'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UBDesktopPalette, qt_meta_tag_ZN16UBDesktopPaletteE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UBDesktopPalette::staticMetaObject = { {
    QMetaObject::SuperData::link<UBActionPalette::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16UBDesktopPaletteE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16UBDesktopPaletteE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16UBDesktopPaletteE_t>.metaTypes,
    nullptr
} };

void UBDesktopPalette::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UBDesktopPalette *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->uniboardClick(); break;
        case 1: _t->customClick(); break;
        case 2: _t->screenClick(); break;
        case 3: _t->refreshMask(); break;
        case 4: _t->stylusToolChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->showHideClick((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->updateShowHideState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->setShowHideButtonVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->setDisplaySelectButtonVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->minimizeMe((*reinterpret_cast<std::add_pointer_t<eMinimizedLocation>>(_a[1]))); break;
        case 10: _t->maximizeMe(); break;
        case 11: _t->parentResized(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UBDesktopPalette::*)()>(_a, &UBDesktopPalette::uniboardClick, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDesktopPalette::*)()>(_a, &UBDesktopPalette::customClick, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDesktopPalette::*)()>(_a, &UBDesktopPalette::screenClick, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDesktopPalette::*)()>(_a, &UBDesktopPalette::refreshMask, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UBDesktopPalette::*)(int )>(_a, &UBDesktopPalette::stylusToolChanged, 4))
            return;
    }
}

const QMetaObject *UBDesktopPalette::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UBDesktopPalette::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16UBDesktopPaletteE_t>.strings))
        return static_cast<void*>(this);
    return UBActionPalette::qt_metacast(_clname);
}

int UBDesktopPalette::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UBActionPalette::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void UBDesktopPalette::uniboardClick()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UBDesktopPalette::customClick()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UBDesktopPalette::screenClick()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UBDesktopPalette::refreshMask()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void UBDesktopPalette::stylusToolChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
